# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nidcpower.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import nidevice_pb2 as nidevice__pb2
from . import session_pb2 as session__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fnidcpower.proto\x12\x0enidcpower_grpc\x1a\x0enidevice.proto\x1a\rsession.proto\"\x82\x01\n\x19NILCRLoadCompensationSpot\x12\x11\n\tfrequency\x18\x01 \x01(\x01\x12\x1c\n\x14reference_value_type\x18\x02 \x01(\x11\x12\x19\n\x11reference_value_a\x18\x03 \x01(\x01\x12\x19\n\x11reference_value_b\x18\x04 \x01(\x01\"\x92\x04\n\x10NILCRMeasurement\x12\x0b\n\x03vdc\x18\x01 \x01(\x01\x12\x0b\n\x03idc\x18\x02 \x01(\x01\x12\x1a\n\x12stimulus_frequency\x18\x03 \x01(\x01\x12\x32\n\nac_voltage\x18\x04 \x01(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\x12\x32\n\nac_current\x18\x05 \x01(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\x12)\n\x01z\x18\x06 \x01(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\x12\x13\n\x0bz_magnitude\x18\x07 \x01(\x01\x12\x0f\n\x07z_phase\x18\x08 \x01(\x01\x12)\n\x01y\x18\t \x01(\x0b\x32\x1e.nidevice_grpc.NIComplexNumber\x12\x13\n\x0by_magnitude\x18\n \x01(\x01\x12\x0f\n\x07y_phase\x18\x0b \x01(\x01\x12\n\n\x02ls\x18\x0c \x01(\x01\x12\n\n\x02\x63s\x18\r \x01(\x01\x12\n\n\x02rs\x18\x0e \x01(\x01\x12\n\n\x02lp\x18\x0f \x01(\x01\x12\n\n\x02\x63p\x18\x10 \x01(\x01\x12\n\n\x02rp\x18\x11 \x01(\x01\x12\t\n\x01\x64\x18\x12 \x01(\x01\x12\t\n\x01q\x18\x13 \x01(\x01\x12\x18\n\x10measurement_mode\x18\x14 \x01(\r\x12\x18\n\x10\x64\x63_in_compliance\x18\x15 \x01(\x08\x12\x18\n\x10\x61\x63_in_compliance\x18\x16 \x01(\x08\x12\x12\n\nunbalanced\x18\x17 \x01(\x08\"2\n\x0c\x41\x62ortRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rAbortResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"T\n\x18\x41\x62ortWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"+\n\x19\x41\x62ortWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"S\n\x17\x43\x61lSelfCalibrateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"*\n\x18\x43\x61lSelfCalibrateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"7\n\x11\x43learErrorRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"$\n\x12\x43learErrorResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"E\n\x1f\x43learInterchangeWarningsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"2\n ClearInterchangeWarningsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe5\x01\n$ClearLatchedOutputCutoffStateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x42\n\x14output_cutoff_reason\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.OutputCutoffReasonH\x00\x12\"\n\x18output_cutoff_reason_raw\x18\x04 \x01(\x11H\x00\x42\x1b\n\x19output_cutoff_reason_enum\"7\n%ClearLatchedOutputCutoffStateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"2\n\x0c\x43loseRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rCloseResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"3\n\rCommitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\" \n\x0e\x43ommitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"U\n\x19\x43ommitWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\",\n\x1a\x43ommitWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc6\x01\n\x1c\x43onfigureApertureTimeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\raperture_time\x18\x03 \x01(\x01\x12\x32\n\x05units\x18\x04 \x01(\x0e\x32!.nidcpower_grpc.ApertureTimeUnitsH\x00\x12\x13\n\tunits_raw\x18\x05 \x01(\x11H\x00\x42\x0c\n\nunits_enum\"/\n\x1d\x43onfigureApertureTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xae\x01\n\x18\x43onfigureAutoZeroRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12-\n\tauto_zero\x18\x03 \x01(\x0e\x32\x18.nidcpower_grpc.AutoZeroH\x00\x12\x17\n\rauto_zero_raw\x18\x04 \x01(\x11H\x00\x42\x10\n\x0e\x61uto_zero_enum\"+\n\x19\x43onfigureAutoZeroResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"g\n\x1c\x43onfigureCurrentLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\x01\"/\n\x1d\x43onfigureCurrentLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigureCurrentLevelRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"4\n\"ConfigureCurrentLevelRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xca\x01\n\x1c\x43onfigureCurrentLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x08\x62\x65havior\x18\x03 \x01(\x0e\x32$.nidcpower_grpc.CurrentLimitBehaviorH\x00\x12\x16\n\x0c\x62\x65havior_raw\x18\x04 \x01(\x11H\x00\x12\r\n\x05limit\x18\x05 \x01(\x01\x42\x0f\n\rbehavior_enum\"/\n\x1d\x43onfigureCurrentLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigureCurrentLimitRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"4\n\"ConfigureCurrentLimitRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb5\x01\n)ConfigureDigitalEdgeMeasureTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0einput_terminal\x18\x02 \x01(\t\x12+\n\x04\x65\x64ge\x18\x03 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x04 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"<\n*ConfigureDigitalEdgeMeasureTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd7\x01\n5ConfigureDigitalEdgeMeasureTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0einput_terminal\x18\x03 \x01(\t\x12+\n\x04\x65\x64ge\x18\x04 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x05 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"H\n6ConfigureDigitalEdgeMeasureTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb3\x01\n\'ConfigureDigitalEdgePulseTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0einput_terminal\x18\x02 \x01(\t\x12+\n\x04\x65\x64ge\x18\x03 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x04 \x01(\x11H\x00\x42\x0b\n\tedge_enum\":\n(ConfigureDigitalEdgePulseTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd5\x01\n3ConfigureDigitalEdgePulseTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0einput_terminal\x18\x03 \x01(\t\x12+\n\x04\x65\x64ge\x18\x04 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x05 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"F\n4ConfigureDigitalEdgePulseTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xbd\x01\n1ConfigureDigitalEdgeSequenceAdvanceTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0einput_terminal\x18\x02 \x01(\t\x12+\n\x04\x65\x64ge\x18\x03 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x04 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"D\n2ConfigureDigitalEdgeSequenceAdvanceTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xdf\x01\n=ConfigureDigitalEdgeSequenceAdvanceTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0einput_terminal\x18\x03 \x01(\t\x12+\n\x04\x65\x64ge\x18\x04 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x05 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"P\n>ConfigureDigitalEdgeSequenceAdvanceTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd8\x01\n6ConfigureDigitalEdgeShutdownTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0einput_terminal\x18\x03 \x01(\t\x12+\n\x04\x65\x64ge\x18\x04 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x05 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"I\n7ConfigureDigitalEdgeShutdownTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb4\x01\n(ConfigureDigitalEdgeSourceTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0einput_terminal\x18\x02 \x01(\t\x12+\n\x04\x65\x64ge\x18\x03 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x04 \x01(\x11H\x00\x42\x0b\n\tedge_enum\";\n)ConfigureDigitalEdgeSourceTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd6\x01\n4ConfigureDigitalEdgeSourceTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0einput_terminal\x18\x03 \x01(\t\x12+\n\x04\x65\x64ge\x18\x04 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x05 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"G\n5ConfigureDigitalEdgeSourceTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb3\x01\n\'ConfigureDigitalEdgeStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x16\n\x0einput_terminal\x18\x02 \x01(\t\x12+\n\x04\x65\x64ge\x18\x03 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x04 \x01(\x11H\x00\x42\x0b\n\tedge_enum\":\n(ConfigureDigitalEdgeStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd5\x01\n3ConfigureDigitalEdgeStartTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x16\n\x0einput_terminal\x18\x03 \x01(\t\x12+\n\x04\x65\x64ge\x18\x04 \x01(\x0e\x32\x1b.nidcpower_grpc.DigitalEdgeH\x00\x12\x12\n\x08\x65\x64ge_raw\x18\x05 \x01(\x11H\x00\x42\x0b\n\tedge_enum\"F\n4ConfigureDigitalEdgeStartTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8e\x01\n*ConfigureLCRCustomCableCompensationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12&\n\x1e\x63ustom_cable_compensation_data\x18\x03 \x01(\x0c\"=\n+ConfigureLCRCustomCableCompensationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"j\n\x1d\x43onfigureOutputEnabledRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"0\n\x1e\x43onfigureOutputEnabledResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb7\x01\n\x1e\x43onfigureOutputFunctionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x32\n\x08\x66unction\x18\x03 \x01(\x0e\x32\x1e.nidcpower_grpc.OutputFunctionH\x00\x12\x16\n\x0c\x66unction_raw\x18\x04 \x01(\x11H\x00\x42\x0f\n\rfunction_enum\"1\n\x1f\x43onfigureOutputFunctionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n ConfigureOutputResistanceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x12\n\nresistance\x18\x03 \x01(\x01\"3\n!ConfigureOutputResistanceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"o\n\x13\x43onfigureOvpRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\r\n\x05limit\x18\x04 \x01(\x01\"&\n\x14\x43onfigureOvpResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xcc\x01\n\"ConfigurePowerLineFrequencyRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x43\n\x13powerline_frequency\x18\x02 \x01(\x0e\x32$.nidcpower_grpc.PowerLineFrequenciesH\x00\x12!\n\x17powerline_frequency_raw\x18\x03 \x01(\x01H\x00\x42\x1a\n\x18powerline_frequency_enum\"5\n#ConfigurePowerLineFrequencyResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n%ConfigurePulseBiasCurrentLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\x01\"8\n&ConfigurePulseBiasCurrentLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n%ConfigurePulseBiasCurrentLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x01\"8\n&ConfigurePulseBiasCurrentLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n%ConfigurePulseBiasVoltageLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\x01\"8\n&ConfigurePulseBiasVoltageLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n%ConfigurePulseBiasVoltageLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x01\"8\n&ConfigurePulseBiasVoltageLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigurePulseCurrentLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\x01\"4\n\"ConfigurePulseCurrentLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"q\n&ConfigurePulseCurrentLevelRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"9\n\'ConfigurePulseCurrentLevelRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigurePulseCurrentLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x01\"4\n\"ConfigurePulseCurrentLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"q\n&ConfigurePulseCurrentLimitRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"9\n\'ConfigurePulseCurrentLimitRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigurePulseVoltageLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\x01\"4\n\"ConfigurePulseVoltageLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"q\n&ConfigurePulseVoltageLevelRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"9\n\'ConfigurePulseVoltageLevelRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigurePulseVoltageLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x01\"4\n\"ConfigurePulseVoltageLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"q\n&ConfigurePulseVoltageLimitRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"9\n\'ConfigurePulseVoltageLimitRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9c\x01\n\x15\x43onfigureSenseRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12&\n\x05sense\x18\x03 \x01(\x0e\x32\x15.nidcpower_grpc.SenseH\x00\x12\x13\n\tsense_raw\x18\x04 \x01(\x11H\x00\x42\x0c\n\nsense_enum\"(\n\x16\x43onfigureSenseResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"P\n*ConfigureSoftwareEdgeMeasureTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"=\n+ConfigureSoftwareEdgeMeasureTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"r\n6ConfigureSoftwareEdgeMeasureTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"I\n7ConfigureSoftwareEdgeMeasureTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"N\n(ConfigureSoftwareEdgePulseTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\";\n)ConfigureSoftwareEdgePulseTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n4ConfigureSoftwareEdgePulseTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"G\n5ConfigureSoftwareEdgePulseTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"X\n2ConfigureSoftwareEdgeSequenceAdvanceTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"E\n3ConfigureSoftwareEdgeSequenceAdvanceTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"z\n>ConfigureSoftwareEdgeSequenceAdvanceTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"Q\n?ConfigureSoftwareEdgeSequenceAdvanceTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"s\n7ConfigureSoftwareEdgeShutdownTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"J\n8ConfigureSoftwareEdgeShutdownTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"O\n)ConfigureSoftwareEdgeSourceTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"<\n*ConfigureSoftwareEdgeSourceTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"q\n5ConfigureSoftwareEdgeSourceTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"H\n6ConfigureSoftwareEdgeSourceTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"N\n(ConfigureSoftwareEdgeStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\";\n)ConfigureSoftwareEdgeStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n4ConfigureSoftwareEdgeStartTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"G\n5ConfigureSoftwareEdgeStartTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xa2\x01\n\x1a\x43onfigureSourceModeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x31\n\x0bsource_mode\x18\x02 \x01(\x0e\x32\x1a.nidcpower_grpc.SourceModeH\x00\x12\x19\n\x0fsource_mode_raw\x18\x03 \x01(\x11H\x00\x42\x12\n\x10source_mode_enum\"-\n\x1b\x43onfigureSourceModeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc4\x01\n&ConfigureSourceModeWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x31\n\x0bsource_mode\x18\x03 \x01(\x0e\x32\x1a.nidcpower_grpc.SourceModeH\x00\x12\x19\n\x0fsource_mode_raw\x18\x04 \x01(\x11H\x00\x42\x12\n\x10source_mode_enum\"9\n\'ConfigureSourceModeWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"g\n\x1c\x43onfigureVoltageLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\x01\"/\n\x1d\x43onfigureVoltageLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigureVoltageLevelRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"4\n\"ConfigureVoltageLevelRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"g\n\x1c\x43onfigureVoltageLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x01\"/\n\x1d\x43onfigureVoltageLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n!ConfigureVoltageLimitRangeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\r\n\x05range\x18\x03 \x01(\x01\"4\n\"ConfigureVoltageLimitRangeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x91\x01\n\x1d\x43reateAdvancedSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rsequence_name\x18\x02 \x01(\t\x12\x15\n\rattribute_ids\x18\x03 \x03(\x11\x12\x1e\n\x16set_as_active_sequence\x18\x04 \x01(\x08\"0\n\x1e\x43reateAdvancedSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x8b\x01\n3CreateAdvancedSequenceCommitStepWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1a\n\x12set_as_active_step\x18\x03 \x01(\x08\"F\n4CreateAdvancedSequenceCommitStepWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"c\n!CreateAdvancedSequenceStepRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x1a\n\x12set_as_active_step\x18\x02 \x01(\x08\"4\n\"CreateAdvancedSequenceStepResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x85\x01\n-CreateAdvancedSequenceStepWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1a\n\x12set_as_active_step\x18\x03 \x01(\x08\"@\n.CreateAdvancedSequenceStepWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xb3\x01\n)CreateAdvancedSequenceWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rsequence_name\x18\x03 \x01(\t\x12\x15\n\rattribute_ids\x18\x04 \x03(\x11\x12\x1e\n\x16set_as_active_sequence\x18\x05 \x01(\x08\"<\n*CreateAdvancedSequenceWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"Z\n\x1d\x44\x65leteAdvancedSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rsequence_name\x18\x02 \x01(\t\"0\n\x1e\x44\x65leteAdvancedSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"|\n)DeleteAdvancedSequenceWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rsequence_name\x18\x03 \x01(\t\"<\n*DeleteAdvancedSequenceWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"4\n\x0e\x44isableRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"!\n\x0f\x44isableResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"@\n\x1a\x44isablePulseTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"-\n\x1b\x44isablePulseTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"b\n&DisablePulseTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"9\n\'DisablePulseTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"J\n$DisableSequenceAdvanceTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"7\n%DisableSequenceAdvanceTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"l\n0DisableSequenceAdvanceTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"C\n1DisableSequenceAdvanceTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"e\n)DisableShutdownTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"<\n*DisableShutdownTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"A\n\x1b\x44isableSourceTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\".\n\x1c\x44isableSourceTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"c\n\'DisableSourceTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\":\n(DisableSourceTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"@\n\x1a\x44isableStartTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"-\n\x1b\x44isableStartTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"b\n&DisableStartTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"9\n\'DisableStartTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"M\n\x13\x45rrorMessageRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x12\n\nerror_code\x18\x02 \x01(\x11\"=\n\x14\x45rrorMessageResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rerror_message\x18\x02 \x01(\t\"7\n\x11\x45rrorQueryRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"O\n\x12\x45rrorQueryResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x12\n\nerror_code\x18\x02 \x01(\x11\x12\x15\n\rerror_message\x18\x03 \x01(\t\"O\n)ExportAttributeConfigurationBufferRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"S\n*ExportAttributeConfigurationBufferResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rconfiguration\x18\x02 \x01(\x0c\"`\n\'ExportAttributeConfigurationFileRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tfile_path\x18\x02 \x01(\t\":\n(ExportAttributeConfigurationFileResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc2\x01\n\x13\x45xportSignalRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12.\n\x06signal\x18\x02 \x01(\x0e\x32\x1c.nidcpower_grpc.ExportSignalH\x00\x12\x14\n\nsignal_raw\x18\x03 \x01(\x11H\x00\x12\x19\n\x11signal_identifier\x18\x04 \x01(\t\x12\x17\n\x0foutput_terminal\x18\x05 \x01(\tB\r\n\x0bsignal_enum\"&\n\x14\x45xportSignalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xe4\x01\n\x1f\x45xportSignalWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12.\n\x06signal\x18\x03 \x01(\x0e\x32\x1c.nidcpower_grpc.ExportSignalH\x00\x12\x14\n\nsignal_raw\x18\x04 \x01(\x11H\x00\x12\x19\n\x11signal_identifier\x18\x05 \x01(\t\x12\x17\n\x0foutput_terminal\x18\x06 \x01(\tB\r\n\x0bsignal_enum\"2\n ExportSignalWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"p\n\x14\x46\x65tchMultipleRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\r\n\x05\x63ount\x18\x04 \x01(\x11\"\x90\x01\n\x15\x46\x65tchMultipleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1c\n\x14voltage_measurements\x18\x02 \x03(\x01\x12\x1c\n\x14\x63urrent_measurements\x18\x03 \x03(\x01\x12\x15\n\rin_compliance\x18\x04 \x03(\x08\x12\x14\n\x0c\x61\x63tual_count\x18\x05 \x01(\x11\"s\n\x17\x46\x65tchMultipleLCRRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\r\n\x05\x63ount\x18\x04 \x01(\x11\"x\n\x18\x46\x65tchMultipleLCRResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x36\n\x0cmeasurements\x18\x02 \x03(\x0b\x32 .nidcpower_grpc.NILCRMeasurement\x12\x14\n\x0c\x61\x63tual_count\x18\x03 \x01(\x11\"\x92\x01\n\x1cGetAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\"H\n\x1dGetAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x08\"\x90\x01\n\x1aGetAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\"F\n\x1bGetAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x11\"\x90\x01\n\x1aGetAttributeViInt64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\"F\n\x1bGetAttributeViInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x03\"\x91\x01\n\x1bGetAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\"G\n\x1cGetAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\x01\"\x92\x01\n\x1cGetAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\"`\n\x1dGetAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12/\n\x0f\x61ttribute_value\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x91\x01\n\x1bGetAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\"G\n\x1cGetAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x61ttribute_value\x18\x02 \x01(\t\"J\n\x15GetChannelNameRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05index\x18\x02 \x01(\x11\">\n\x16GetChannelNameResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"T\n\x1fGetChannelNameFromStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\r\n\x05index\x18\x02 \x01(\t\"H\n GetChannelNameFromStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"5\n\x0fGetErrorRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"E\n\x10GetErrorResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x11\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"E\n\x1fGetExtCalLastDateAndTimeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"z\n GetExtCalLastDateAndTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\x11\x12\r\n\x05month\x18\x03 \x01(\x11\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\x11\x12\x0c\n\x04hour\x18\x05 \x01(\x11\x12\x0e\n\x06minute\x18\x06 \x01(\x11\">\n\x18GetExtCalLastTempRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"@\n\x19GetExtCalLastTempResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\"I\n#GetExtCalRecommendedIntervalRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"F\n$GetExtCalRecommendedIntervalResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0e\n\x06months\x18\x02 \x01(\x11\"\xe1\x01\n(GetLCRCompensationLastDateAndTimeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12@\n\x11\x63ompensation_type\x18\x03 \x01(\x0e\x32#.nidcpower_grpc.LCRCompensationTypeH\x00\x12\x1f\n\x15\x63ompensation_type_raw\x18\x04 \x01(\x11H\x00\x42\x18\n\x16\x63ompensation_type_enum\"\x83\x01\n)GetLCRCompensationLastDateAndTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\x11\x12\r\n\x05month\x18\x03 \x01(\x11\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\x11\x12\x0c\n\x04hour\x18\x05 \x01(\x11\x12\x0e\n\x06minute\x18\x06 \x01(\x11\"d\n(GetLCRCustomCableCompensationDataRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"c\n)GetLCRCustomCableCompensationDataResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12&\n\x1e\x63ustom_cable_compensation_data\x18\x02 \x01(\x0c\"B\n\x1cGetNextCoercionRecordRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"H\n\x1dGetNextCoercionRecordResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x17\n\x0f\x63oercion_record\x18\x02 \x01(\t\"F\n GetNextInterchangeWarningRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"P\n!GetNextInterchangeWarningResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1b\n\x13interchange_warning\x18\x02 \x01(\t\"F\n GetSelfCalLastDateAndTimeRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"{\n!GetSelfCalLastDateAndTimeResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x0c\n\x04year\x18\x02 \x01(\x11\x12\r\n\x05month\x18\x03 \x01(\x11\x12\x0b\n\x03\x64\x61y\x18\x04 \x01(\x11\x12\x0c\n\x04hour\x18\x05 \x01(\x11\x12\x0e\n\x06minute\x18\x06 \x01(\x11\"?\n\x19GetSelfCalLastTempRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"A\n\x1aGetSelfCalLastTempResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\"f\n)ImportAttributeConfigurationBufferRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rconfiguration\x18\x02 \x01(\x0c\"<\n*ImportAttributeConfigurationBufferResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"`\n\'ImportAttributeConfigurationFileRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x11\n\tfile_path\x18\x02 \x01(\t\":\n(ImportAttributeConfigurationFileResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xd3\x01\n\x1dInitializeWithChannelsRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x10\n\x08\x63hannels\x18\x03 \x01(\t\x12\r\n\x05reset\x18\x04 \x01(\x08\x12\x15\n\roption_string\x18\x05 \x01(\t\x12M\n\x17initialization_behavior\x18\x06 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"\x90\x01\n\x1eInitializeWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"\xcc\x01\n(InitializeWithIndependentChannelsRequest\x12\x14\n\x0csession_name\x18\x01 \x01(\t\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\r\n\x05reset\x18\x03 \x01(\x08\x12\x15\n\roption_string\x18\x04 \x01(\t\x12M\n\x17initialization_behavior\x18\x05 \x01(\x0e\x32,.nidevice_grpc.SessionInitializationBehavior\"\x9b\x01\n)InitializeWithIndependentChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x02vi\x18\x02 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x19\n\rerror_message\x18\x03 \x01(\tB\x02\x18\x01\x12\x1f\n\x17new_session_initialized\x18\x04 \x01(\x08\"5\n\x0fInitiateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\"\n\x10InitiateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"W\n\x1bInitiateWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\".\n\x1cInitiateWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"D\n\x1eInvalidateAllAttributesRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"1\n\x1fInvalidateAllAttributesResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc1\x01\n\x0eMeasureRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12<\n\x10measurement_type\x18\x03 \x01(\x0e\x32 .nidcpower_grpc.MeasurementTypesH\x00\x12\x1e\n\x14measurement_type_raw\x18\x04 \x01(\x11H\x00\x42\x17\n\x15measurement_type_enum\"6\n\x0fMeasureResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0bmeasurement\x18\x02 \x01(\x01\"R\n\x16MeasureMultipleRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"e\n\x17MeasureMultipleResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1c\n\x14voltage_measurements\x18\x02 \x03(\x01\x12\x1c\n\x14\x63urrent_measurements\x18\x03 \x03(\x01\"U\n\x19MeasureMultipleLCRRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"d\n\x1aMeasureMultipleLCRResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x36\n\x0cmeasurements\x18\x02 \x03(\x0b\x32 .nidcpower_grpc.NILCRMeasurement\"\xa4\x01\n!PerformLCRLoadCompensationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x45\n\x12\x63ompensation_spots\x18\x03 \x03(\x0b\x32).nidcpower_grpc.NILCRLoadCompensationSpot\"4\n\"PerformLCRLoadCompensationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"}\n!PerformLCROpenCompensationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1e\n\x16\x61\x64\x64itional_frequencies\x18\x03 \x03(\x01\"4\n\"PerformLCROpenCompensationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"h\n,PerformLCROpenCustomCableCompensationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"?\n-PerformLCROpenCustomCableCompensationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"~\n\"PerformLCRShortCompensationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x1e\n\x16\x61\x64\x64itional_frequencies\x18\x03 \x03(\x01\"5\n#PerformLCRShortCompensationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"i\n-PerformLCRShortCustomCableCompensationRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"@\n.PerformLCRShortCustomCableCompensationResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"T\n\x18QueryInComplianceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"B\n\x19QueryInComplianceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x15\n\rin_compliance\x18\x02 \x01(\x08\"\xe5\x01\n$QueryLatchedOutputCutoffStateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x42\n\x14output_cutoff_reason\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.OutputCutoffReasonH\x00\x12\"\n\x18output_cutoff_reason_raw\x18\x04 \x01(\x11H\x00\x42\x1b\n\x19output_cutoff_reason_enum\"T\n%QueryLatchedOutputCutoffStateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x1b\n\x13output_cutoff_state\x18\x02 \x01(\x08\"n\n\x1bQueryMaxCurrentLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rvoltage_level\x18\x03 \x01(\x01\"I\n\x1cQueryMaxCurrentLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x19\n\x11max_current_limit\x18\x02 \x01(\x01\"n\n\x1bQueryMaxVoltageLevelRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rcurrent_limit\x18\x03 \x01(\x01\"I\n\x1cQueryMaxVoltageLevelResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x19\n\x11max_voltage_level\x18\x02 \x01(\x01\"n\n\x1bQueryMinCurrentLimitRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x15\n\rvoltage_level\x18\x03 \x01(\x01\"I\n\x1cQueryMinCurrentLimitResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x19\n\x11min_current_limit\x18\x02 \x01(\x01\"\xba\x01\n\x17QueryOutputStateRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x34\n\x0coutput_state\x18\x03 \x01(\x0e\x32\x1c.nidcpower_grpc.OutputStatesH\x00\x12\x1a\n\x10output_state_raw\x18\x04 \x01(\x11H\x00\x42\x13\n\x11output_state_enum\"<\n\x18QueryOutputStateResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x10\n\x08in_state\x18\x02 \x01(\x08\"C\n\x1dReadCurrentTemperatureRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"E\n\x1eReadCurrentTemperatureResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x13\n\x0btemperature\x18\x02 \x01(\x01\"2\n\x0cResetRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"\x1f\n\rResetResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"8\n\x12ResetDeviceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"%\n\x13ResetDeviceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"B\n\x1cResetInterchangeCheckRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"/\n\x1dResetInterchangeCheckResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"T\n\x18ResetWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\"+\n\x19ResetWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\">\n\x18ResetWithDefaultsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"+\n\x19ResetWithDefaultsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\":\n\x14RevisionQueryRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"f\n\x15RevisionQueryResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\"\n\x1ainstrument_driver_revision\x18\x02 \x01(\t\x12\x19\n\x11\x66irmware_revision\x18\x03 \x01(\t\"5\n\x0fSelfTestRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\"W\n\x10SelfTestResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\x12\x18\n\x10self_test_result\x18\x02 \x01(\x11\x12\x19\n\x11self_test_message\x18\x03 \x01(\t\"\xab\x01\n\x1eSendSoftwareEdgeTriggerRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12>\n\x07trigger\x18\x02 \x01(\x0e\x32+.nidcpower_grpc.SendSoftwareEdgeTriggerTypeH\x00\x12\x15\n\x0btrigger_raw\x18\x03 \x01(\x11H\x00\x42\x0e\n\x0ctrigger_enum\"1\n\x1fSendSoftwareEdgeTriggerResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xcd\x01\n*SendSoftwareEdgeTriggerWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12>\n\x07trigger\x18\x03 \x01(\x0e\x32+.nidcpower_grpc.SendSoftwareEdgeTriggerTypeH\x00\x12\x15\n\x0btrigger_raw\x18\x04 \x01(\x11H\x00\x42\x0e\n\x0ctrigger_enum\"=\n+SendSoftwareEdgeTriggerWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xab\x01\n\x1cSetAttributeViBooleanRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\x12\x17\n\x0f\x61ttribute_value\x18\x04 \x01(\x08\"/\n\x1dSetAttributeViBooleanResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x91\x02\n\x1aSetAttributeViInt32Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\x12H\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32-.nidcpower_grpc.NiDCPowerInt32AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x11H\x00\x42\x16\n\x14\x61ttribute_value_enum\"-\n\x1bSetAttributeViInt32Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xad\x01\n\x1aSetAttributeViInt64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\x03\"-\n\x1bSetAttributeViInt64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x93\x02\n\x1bSetAttributeViReal64Request\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\x12I\n\x0f\x61ttribute_value\x18\x04 \x01(\x0e\x32..nidcpower_grpc.NiDCPowerReal64AttributeValuesH\x00\x12\x1d\n\x13\x61ttribute_value_raw\x18\x05 \x01(\x01H\x00\x42\x16\n\x14\x61ttribute_value_enum\".\n\x1cSetAttributeViReal64Response\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc3\x01\n\x1cSetAttributeViSessionRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\x12/\n\x0f\x61ttribute_value\x18\x04 \x01(\x0b\x32\x16.nidevice_grpc.Session\"/\n\x1dSetAttributeViSessionResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xae\x01\n\x1bSetAttributeViStringRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x38\n\x0c\x61ttribute_id\x18\x03 \x01(\x0e\x32\".nidcpower_grpc.NiDCPowerAttribute\x12\x1b\n\x13\x61ttribute_value_raw\x18\x04 \x01(\t\".\n\x1cSetAttributeViStringResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"u\n\x12SetSequenceRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\x01\x12\x15\n\rsource_delays\x18\x04 \x03(\x01\"%\n\x13SetSequenceResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\x9e\x01\n\x13WaitForEventRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12)\n\x08\x65vent_id\x18\x02 \x01(\x0e\x32\x15.nidcpower_grpc.EventH\x00\x12\x16\n\x0c\x65vent_id_raw\x18\x03 \x01(\x11H\x00\x12\x0f\n\x07timeout\x18\x04 \x01(\x01\x42\x0f\n\revent_id_enum\"&\n\x14WaitForEventResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05\"\xc0\x01\n\x1fWaitForEventWithChannelsRequest\x12\"\n\x02vi\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12)\n\x08\x65vent_id\x18\x03 \x01(\x0e\x32\x15.nidcpower_grpc.EventH\x00\x12\x16\n\x0c\x65vent_id_raw\x18\x04 \x01(\x11H\x00\x12\x0f\n\x07timeout\x18\x05 \x01(\x01\x42\x0f\n\revent_id_enum\"2\n WaitForEventWithChannelsResponse\x12\x0e\n\x06status\x18\x01 \x01(\x05*\xd1Z\n\x12NiDCPowerAttribute\x12#\n\x1fNIDCPOWER_ATTRIBUTE_UNSPECIFIED\x10\x00\x12%\n\x1fNIDCPOWER_ATTRIBUTE_RANGE_CHECK\x10\x92\x8b@\x12\x31\n+NIDCPOWER_ATTRIBUTE_QUERY_INSTRUMENT_STATUS\x10\x93\x8b@\x12\x1f\n\x19NIDCPOWER_ATTRIBUTE_CACHE\x10\x94\x8b@\x12\"\n\x1cNIDCPOWER_ATTRIBUTE_SIMULATE\x10\x95\x8b@\x12*\n$NIDCPOWER_ATTRIBUTE_RECORD_COERCIONS\x10\x96\x8b@\x12&\n NIDCPOWER_ATTRIBUTE_DRIVER_SETUP\x10\x97\x8b@\x12+\n%NIDCPOWER_ATTRIBUTE_INTERCHANGE_CHECK\x10\xa5\x8b@\x12\'\n!NIDCPOWER_ATTRIBUTE_CHANNEL_COUNT\x10\xdb\x8c@\x12\x30\n*NIDCPOWER_ATTRIBUTE_SPECIFIC_DRIVER_PREFIX\x10\xbe\x8d@\x12\x30\n*NIDCPOWER_ATTRIBUTE_IO_RESOURCE_DESCRIPTOR\x10\xc0\x8d@\x12&\n NIDCPOWER_ATTRIBUTE_LOGICAL_NAME\x10\xc1\x8d@\x12\x35\n/NIDCPOWER_ATTRIBUTE_SUPPORTED_INSTRUMENT_MODELS\x10\xd7\x8d@\x12,\n&NIDCPOWER_ATTRIBUTE_GROUP_CAPABILITIES\x10\xa1\x8e@\x12\x36\n0NIDCPOWER_ATTRIBUTE_INSTRUMENT_FIRMWARE_REVISION\x10\x8e\x8f@\x12\x31\n+NIDCPOWER_ATTRIBUTE_INSTRUMENT_MANUFACTURER\x10\x8f\x8f@\x12*\n$NIDCPOWER_ATTRIBUTE_INSTRUMENT_MODEL\x10\x90\x8f@\x12\x30\n*NIDCPOWER_ATTRIBUTE_SPECIFIC_DRIVER_VENDOR\x10\x91\x8f@\x12\x35\n/NIDCPOWER_ATTRIBUTE_SPECIFIC_DRIVER_DESCRIPTION\x10\x92\x8f@\x12\x42\n<NIDCPOWER_ATTRIBUTE_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION\x10\x93\x8f@\x12\x42\n<NIDCPOWER_ATTRIBUTE_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION\x10\x94\x8f@\x12\x32\n,NIDCPOWER_ATTRIBUTE_SPECIFIC_DRIVER_REVISION\x10\xb7\x8f@\x12&\n NIDCPOWER_ATTRIBUTE_POWER_SOURCE\x10\xb0\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_POWER_SOURCE_IN_USE\x10\xb1\x98\x46\x12:\n4NIDCPOWER_ATTRIBUTE_AUXILIARY_POWER_SOURCE_AVAILABLE\x10\xb2\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_SAMPLES_TO_AVERAGE\x10\xb3\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_CURRENT_LIMIT_RANGE\x10\xb4\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_VOLTAGE_LEVEL_RANGE\x10\xb5\x98\x46\x12:\n4NIDCPOWER_ATTRIBUTE_RESET_AVERAGE_BEFORE_MEASUREMENT\x10\xb6\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_OVERRANGING_ENABLED\x10\xb7\x98\x46\x12)\n#NIDCPOWER_ATTRIBUTE_OUTPUT_FUNCTION\x10\xb8\x98\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_CURRENT_LEVEL\x10\xb9\x98\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_VOLTAGE_LIMIT\x10\xba\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_CURRENT_LEVEL_RANGE\x10\xbb\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_VOLTAGE_LIMIT_RANGE\x10\xbc\x98\x46\x12\x1f\n\x19NIDCPOWER_ATTRIBUTE_SENSE\x10\xbd\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_OUTPUT_CAPACITANCE\x10\xbe\x98\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_VOLTAGE_LEVEL_AUTORANGE\x10\xbf\x98\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_CURRENT_LIMIT_AUTORANGE\x10\xc0\x98\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_CURRENT_LEVEL_AUTORANGE\x10\xc1\x98\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_VOLTAGE_LIMIT_AUTORANGE\x10\xc2\x98\x46\x12.\n(NIDCPOWER_ATTRIBUTE_POWER_LINE_FREQUENCY\x10\xc4\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_START_TRIGGER_TYPE\x10\xc5\x98\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_START_TRIGGER_EDGE\x10\xc6\x98\x46\x12\x43\n=NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_START_TRIGGER_INPUT_TERMINAL\x10\xc7\x98\x46\x12@\n:NIDCPOWER_ATTRIBUTE_EXPORTED_START_TRIGGER_OUTPUT_TERMINAL\x10\xc8\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_SEQUENCE_LOOP_COUNT\x10\xc9\x98\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_SEQUENCE_ADVANCE_TRIGGER_TYPE\x10\xca\x98\x46\x12\x44\n>NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_SEQUENCE_ADVANCE_TRIGGER_EDGE\x10\xcb\x98\x46\x12N\nHNIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_SEQUENCE_ADVANCE_TRIGGER_INPUT_TERMINAL\x10\xcc\x98\x46\x12K\nENIDCPOWER_ATTRIBUTE_EXPORTED_SEQUENCE_ADVANCE_TRIGGER_OUTPUT_TERMINAL\x10\xcd\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_SOURCE_TRIGGER_TYPE\x10\xce\x98\x46\x12:\n4NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_SOURCE_TRIGGER_EDGE\x10\xcf\x98\x46\x12\x44\n>NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_SOURCE_TRIGGER_INPUT_TERMINAL\x10\xd0\x98\x46\x12\x41\n;NIDCPOWER_ATTRIBUTE_EXPORTED_SOURCE_TRIGGER_OUTPUT_TERMINAL\x10\xd1\x98\x46\x12.\n(NIDCPOWER_ATTRIBUTE_MEASURE_TRIGGER_TYPE\x10\xd2\x98\x46\x12;\n5NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_MEASURE_TRIGGER_EDGE\x10\xd3\x98\x46\x12\x45\n?NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_MEASURE_TRIGGER_INPUT_TERMINAL\x10\xd4\x98\x46\x12\x42\n<NIDCPOWER_ATTRIBUTE_EXPORTED_MEASURE_TRIGGER_OUTPUT_TERMINAL\x10\xd5\x98\x46\x12J\nDNIDCPOWER_ATTRIBUTE_SEQUENCE_ITERATION_COMPLETE_EVENT_PULSE_POLARITY\x10\xd6\x98\x46\x12G\nANIDCPOWER_ATTRIBUTE_SEQUENCE_ITERATION_COMPLETE_EVENT_PULSE_WIDTH\x10\xd7\x98\x46\x12K\nENIDCPOWER_ATTRIBUTE_SEQUENCE_ITERATION_COMPLETE_EVENT_OUTPUT_TERMINAL\x10\xd8\x98\x46\x12>\n8NIDCPOWER_ATTRIBUTE_SOURCE_COMPLETE_EVENT_PULSE_POLARITY\x10\xd9\x98\x46\x12;\n5NIDCPOWER_ATTRIBUTE_SOURCE_COMPLETE_EVENT_PULSE_WIDTH\x10\xda\x98\x46\x12?\n9NIDCPOWER_ATTRIBUTE_SOURCE_COMPLETE_EVENT_OUTPUT_TERMINAL\x10\xdb\x98\x46\x12?\n9NIDCPOWER_ATTRIBUTE_MEASURE_COMPLETE_EVENT_PULSE_POLARITY\x10\xdc\x98\x46\x12<\n6NIDCPOWER_ATTRIBUTE_MEASURE_COMPLETE_EVENT_PULSE_WIDTH\x10\xdd\x98\x46\x12\x36\n0NIDCPOWER_ATTRIBUTE_MEASURE_COMPLETE_EVENT_DELAY\x10\xde\x98\x46\x12@\n:NIDCPOWER_ATTRIBUTE_MEASURE_COMPLETE_EVENT_OUTPUT_TERMINAL\x10\xdf\x98\x46\x12\x43\n=NIDCPOWER_ATTRIBUTE_SEQUENCE_ENGINE_DONE_EVENT_PULSE_POLARITY\x10\xe0\x98\x46\x12@\n:NIDCPOWER_ATTRIBUTE_SEQUENCE_ENGINE_DONE_EVENT_PULSE_WIDTH\x10\xe1\x98\x46\x12\x44\n>NIDCPOWER_ATTRIBUTE_SEQUENCE_ENGINE_DONE_EVENT_OUTPUT_TERMINAL\x10\xe2\x98\x46\x12&\n NIDCPOWER_ATTRIBUTE_SOURCE_DELAY\x10\xe3\x98\x46\x12%\n\x1fNIDCPOWER_ATTRIBUTE_SOURCE_MODE\x10\xe6\x98\x46\x12#\n\x1dNIDCPOWER_ATTRIBUTE_AUTO_ZERO\x10\xe7\x98\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_FETCH_BACKLOG\x10\xe8\x98\x46\x12&\n NIDCPOWER_ATTRIBUTE_MEASURE_WHEN\x10\xe9\x98\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_APERTURE_TIME\x10\xea\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_APERTURE_TIME_UNITS\x10\xeb\x98\x46\x12*\n$NIDCPOWER_ATTRIBUTE_OUTPUT_CONNECTED\x10\xec\x98\x46\x12+\n%NIDCPOWER_ATTRIBUTE_OUTPUT_RESISTANCE\x10\xed\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_TRANSIENT_RESPONSE\x10\xee\x98\x46\x12/\n)NIDCPOWER_ATTRIBUTE_MEASURE_RECORD_LENGTH\x10\xef\x98\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_MEASURE_RECORD_LENGTH_IS_FINITE\x10\xf0\x98\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_MEASURE_RECORD_DELTA_TIME\x10\xf1\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_DC_NOISE_REJECTION\x10\xf2\x98\x46\x12\x30\n*NIDCPOWER_ATTRIBUTE_VOLTAGE_GAIN_BANDWIDTH\x10\xf3\x98\x46\x12\x38\n2NIDCPOWER_ATTRIBUTE_VOLTAGE_COMPENSATION_FREQUENCY\x10\xf4\x98\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_VOLTAGE_POLE_ZERO_RATIO\x10\xf5\x98\x46\x12\x30\n*NIDCPOWER_ATTRIBUTE_CURRENT_GAIN_BANDWIDTH\x10\xf6\x98\x46\x12\x38\n2NIDCPOWER_ATTRIBUTE_CURRENT_COMPENSATION_FREQUENCY\x10\xf7\x98\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_CURRENT_POLE_ZERO_RATIO\x10\xf8\x98\x46\x12\x36\n0NIDCPOWER_ATTRIBUTE_SELF_CALIBRATION_PERSISTENCE\x10\xf9\x98\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_ACTIVE_ADVANCED_SEQUENCE\x10\xfa\x98\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_ACTIVE_ADVANCED_SEQUENCE_STEP\x10\xfb\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_MEASURE_BUFFER_SIZE\x10\xfd\x98\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_SEQUENCE_LOOP_COUNT_IS_FINITE\x10\xfe\x98\x46\x12,\n&NIDCPOWER_ATTRIBUTE_SUPPORT_OUTPUT_DMA\x10\xff\x98\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_PULSE_VOLTAGE_LEVEL\x10\x80\x99\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_PULSE_CURRENT_LIMIT\x10\x81\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_PULSE_BIAS_VOLTAGE_LEVEL\x10\x82\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_PULSE_BIAS_CURRENT_LIMIT\x10\x83\x99\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_PULSE_VOLTAGE_LEVEL_RANGE\x10\x84\x99\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_PULSE_CURRENT_LIMIT_RANGE\x10\x85\x99\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_PULSE_CURRENT_LEVEL\x10\x86\x99\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_PULSE_VOLTAGE_LIMIT\x10\x87\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_PULSE_BIAS_CURRENT_LEVEL\x10\x88\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_PULSE_BIAS_VOLTAGE_LIMIT\x10\x89\x99\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_PULSE_CURRENT_LEVEL_RANGE\x10\x8a\x99\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_PULSE_VOLTAGE_LIMIT_RANGE\x10\x8b\x99\x46\x12*\n$NIDCPOWER_ATTRIBUTE_PULSE_BIAS_DELAY\x10\x8c\x99\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_PULSE_ON_TIME\x10\x8d\x99\x46\x12(\n\"NIDCPOWER_ATTRIBUTE_PULSE_OFF_TIME\x10\x8e\x99\x46\x12,\n&NIDCPOWER_ATTRIBUTE_PULSE_TRIGGER_TYPE\x10\x8f\x99\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_PULSE_TRIGGER_EDGE\x10\x90\x99\x46\x12\x43\n=NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_PULSE_TRIGGER_INPUT_TERMINAL\x10\x91\x99\x46\x12@\n:NIDCPOWER_ATTRIBUTE_EXPORTED_PULSE_TRIGGER_OUTPUT_TERMINAL\x10\x92\x99\x46\x12>\n8NIDCPOWER_ATTRIBUTE_PULSE_COMPLETE_EVENT_OUTPUT_TERMINAL\x10\x93\x99\x46\x12=\n7NIDCPOWER_ATTRIBUTE_PULSE_COMPLETE_EVENT_PULSE_POLARITY\x10\x94\x99\x46\x12:\n4NIDCPOWER_ATTRIBUTE_PULSE_COMPLETE_EVENT_PULSE_WIDTH\x10\x95\x99\x46\x12G\nANIDCPOWER_ATTRIBUTE_READY_FOR_PULSE_TRIGGER_EVENT_OUTPUT_TERMINAL\x10\x96\x99\x46\x12\x46\n@NIDCPOWER_ATTRIBUTE_READY_FOR_PULSE_TRIGGER_EVENT_PULSE_POLARITY\x10\x97\x99\x46\x12\x43\n=NIDCPOWER_ATTRIBUTE_READY_FOR_PULSE_TRIGGER_EVENT_PULSE_WIDTH\x10\x98\x99\x46\x12.\n(NIDCPOWER_ATTRIBUTE_INTERLOCK_INPUT_OPEN\x10\x99\x99\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_INSTRUMENT_API_SESSION_HANDLE\x10\x9e\x99\x46\x12T\nNNIDCPOWER_ATTRIBUTE_WAS_SESSION_OPENED_BY_INITIALIZE_WITH_INDEPENDENT_CHANNELS\x10\x9f\x99\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_SERIAL_NUMBER\x10\xc8\x99\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_COMPLIANCE_LIMIT_SYMMETRY\x10\xe8\x99\x46\x12,\n&NIDCPOWER_ATTRIBUTE_VOLTAGE_LIMIT_HIGH\x10\xe9\x99\x46\x12+\n%NIDCPOWER_ATTRIBUTE_VOLTAGE_LIMIT_LOW\x10\xea\x99\x46\x12,\n&NIDCPOWER_ATTRIBUTE_CURRENT_LIMIT_HIGH\x10\xeb\x99\x46\x12+\n%NIDCPOWER_ATTRIBUTE_CURRENT_LIMIT_LOW\x10\xec\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_PULSE_VOLTAGE_LIMIT_HIGH\x10\xed\x99\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_PULSE_VOLTAGE_LIMIT_LOW\x10\xee\x99\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_PULSE_BIAS_VOLTAGE_LIMIT_HIGH\x10\xef\x99\x46\x12\x36\n0NIDCPOWER_ATTRIBUTE_PULSE_BIAS_VOLTAGE_LIMIT_LOW\x10\xf0\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_PULSE_CURRENT_LIMIT_HIGH\x10\xf1\x99\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_PULSE_CURRENT_LIMIT_LOW\x10\xf2\x99\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_PULSE_BIAS_CURRENT_LIMIT_HIGH\x10\xf3\x99\x46\x12\x36\n0NIDCPOWER_ATTRIBUTE_PULSE_BIAS_CURRENT_LIMIT_LOW\x10\xf4\x99\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_SEQUENCE_STEP_DELTA_TIME\x10\xf6\x99\x46\x12:\n4NIDCPOWER_ATTRIBUTE_SEQUENCE_STEP_DELTA_TIME_ENABLED\x10\xf7\x99\x46\x12.\n(NIDCPOWER_ATTRIBUTE_OCP_ERROR_PERCENTAGE\x10\xf8\x99\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_ACTUAL_POWER_ALLOCATION\x10\xfd\x99\x46\x12\x34\n.NIDCPOWER_ATTRIBUTE_REQUESTED_POWER_ALLOCATION\x10\xfe\x99\x46\x12/\n)NIDCPOWER_ATTRIBUTE_POWER_ALLOCATION_MODE\x10\xff\x99\x46\x12)\n#NIDCPOWER_ATTRIBUTE_INSTRUMENT_MODE\x10\x80\x9a\x46\x12/\n)NIDCPOWER_ATTRIBUTE_LCR_STIMULUS_FUNCTION\x10\x81\x9a\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_LCR_FREQUENCY\x10\x82\x9a\x46\x12/\n)NIDCPOWER_ATTRIBUTE_LCR_VOLTAGE_AMPLITUDE\x10\x83\x9a\x46\x12/\n)NIDCPOWER_ATTRIBUTE_LCR_CURRENT_AMPLITUDE\x10\x84\x9a\x46\x12,\n&NIDCPOWER_ATTRIBUTE_LCR_DC_BIAS_SOURCE\x10\x85\x9a\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_LCR_DC_BIAS_VOLTAGE_LEVEL\x10\x86\x9a\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_LCR_DC_BIAS_CURRENT_LEVEL\x10\x87\x9a\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_LCR_IMPEDANCE_AUTO_RANGE\x10\x88\x9a\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_LCR_IMPEDANCE_RANGE\x10\x89\x9a\x46\x12.\n(NIDCPOWER_ATTRIBUTE_LCR_MEASUREMENT_TIME\x10\x8a\x9a\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_LCR_OPEN_COMPENSATION_ENABLED\x10\x8c\x9a\x46\x12\x38\n2NIDCPOWER_ATTRIBUTE_LCR_SHORT_COMPENSATION_ENABLED\x10\x8d\x9a\x46\x12\x37\n1NIDCPOWER_ATTRIBUTE_LCR_LOAD_COMPENSATION_ENABLED\x10\x8e\x9a\x46\x12\x46\n@NIDCPOWER_ATTRIBUTE_LCR_OPEN_SHORT_LOAD_COMPENSATION_DATA_SOURCE\x10\x8f\x9a\x46\x12/\n)NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_ENABLED\x10\x9b\x9a\x46\x12\x41\n;NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_VOLTAGE_OUTPUT_LIMIT_HIGH\x10\x9c\x9a\x46\x12\x42\n<NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_CURRENT_MEASURE_LIMIT_HIGH\x10\x9d\x9a\x46\x12@\n:NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_VOLTAGE_CHANGE_LIMIT_LOW\x10\x9e\x9a\x46\x12@\n:NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_CURRENT_CHANGE_LIMIT_LOW\x10\x9f\x9a\x46\x12\x41\n;NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_CURRENT_OVERRANGE_ENABLED\x10\xa0\x9a\x46\x12#\n\x1dNIDCPOWER_ATTRIBUTE_AUTORANGE\x10\xa4\x9a\x46\x12,\n&NIDCPOWER_ATTRIBUTE_AUTORANGE_BEHAVIOR\x10\xa5\x9a\x46\x12\x36\n0NIDCPOWER_ATTRIBUTE_AUTORANGE_APERTURE_TIME_MODE\x10\xa6\x9a\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_AUTORANGE_MINIMUM_APERTURE_TIME\x10\xa7\x9a\x46\x12?\n9NIDCPOWER_ATTRIBUTE_AUTORANGE_MINIMUM_APERTURE_TIME_UNITS\x10\xa8\x9a\x46\x12)\n#NIDCPOWER_ATTRIBUTE_MERGED_CHANNELS\x10\xa9\x9a\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_AUTORANGE_MINIMUM_CURRENT_RANGE\x10\xaf\x9a\x46\x12\x39\n3NIDCPOWER_ATTRIBUTE_AUTORANGE_MINIMUM_VOLTAGE_RANGE\x10\xb0\x9a\x46\x12\x32\n,NIDCPOWER_ATTRIBUTE_AUTORANGE_THRESHOLD_MODE\x10\xb1\x9a\x46\x12\x35\n/NIDCPOWER_ATTRIBUTE_LCR_CUSTOM_MEASUREMENT_TIME\x10\xb2\x9a\x46\x12=\n7NIDCPOWER_ATTRIBUTE_ACTUAL_VOLTAGE_RANGE_FOR_LAST_FETCH\x10\xb3\x9a\x46\x12=\n7NIDCPOWER_ATTRIBUTE_ACTUAL_CURRENT_RANGE_FOR_LAST_FETCH\x10\xb4\x9a\x46\x12.\n(NIDCPOWER_ATTRIBUTE_LCR_OPEN_CONDUCTANCE\x10\xb5\x9a\x46\x12.\n(NIDCPOWER_ATTRIBUTE_LCR_OPEN_SUSCEPTANCE\x10\xb6\x9a\x46\x12.\n(NIDCPOWER_ATTRIBUTE_LCR_SHORT_RESISTANCE\x10\xb7\x9a\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_LCR_SHORT_REACTANCE\x10\xb8\x9a\x46\x12+\n%NIDCPOWER_ATTRIBUTE_LCR_VOLTAGE_RANGE\x10\xb9\x9a\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_LCR_DC_BIAS_VOLTAGE_RANGE\x10\xba\x9a\x46\x12+\n%NIDCPOWER_ATTRIBUTE_LCR_CURRENT_RANGE\x10\xbb\x9a\x46\x12\x36\n0NIDCPOWER_ATTRIBUTE_LCR_MEASURED_LOAD_RESISTANCE\x10\xbc\x9a\x46\x12\x35\n/NIDCPOWER_ATTRIBUTE_LCR_MEASURED_LOAD_REACTANCE\x10\xbd\x9a\x46\x12\x34\n.NIDCPOWER_ATTRIBUTE_LCR_ACTUAL_LOAD_RESISTANCE\x10\xbe\x9a\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_LCR_ACTUAL_LOAD_REACTANCE\x10\xbf\x9a\x46\x12\x33\n-NIDCPOWER_ATTRIBUTE_LCR_DC_BIAS_CURRENT_RANGE\x10\xc2\x9a\x46\x12/\n)NIDCPOWER_ATTRIBUTE_SHUTDOWN_TRIGGER_TYPE\x10\xc3\x9a\x46\x12<\n6NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_SHUTDOWN_TRIGGER_EDGE\x10\xc4\x9a\x46\x12\x46\n@NIDCPOWER_ATTRIBUTE_DIGITAL_EDGE_SHUTDOWN_TRIGGER_INPUT_TERMINAL\x10\xc5\x9a\x46\x12&\n NIDCPOWER_ATTRIBUTE_CABLE_LENGTH\x10\xc6\x9a\x46\x12\x35\n/NIDCPOWER_ATTRIBUTE_LCR_AUTOMATIC_LEVEL_CONTROL\x10\xd2\x9a\x46\x12=\n7NIDCPOWER_ATTRIBUTE_LCR_DC_BIAS_AUTOMATIC_LEVEL_CONTROL\x10\xd3\x9a\x46\x12@\n:NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_VOLTAGE_OUTPUT_LIMIT_LOW\x10\xd4\x9a\x46\x12\x41\n;NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_CURRENT_MEASURE_LIMIT_LOW\x10\xd5\x9a\x46\x12\x41\n;NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_VOLTAGE_CHANGE_LIMIT_HIGH\x10\xd6\x9a\x46\x12\x41\n;NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_CURRENT_CHANGE_LIMIT_HIGH\x10\xd7\x9a\x46\x12\x45\n?NIDCPOWER_ATTRIBUTE_LCR_SHORT_CUSTOM_CABLE_COMPENSATION_ENABLED\x10\xdb\x9a\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_OUTPUT_CUTOFF_DELAY\x10\xdc\x9a\x46\x12)\n#NIDCPOWER_ATTRIBUTE_ISOLATION_STATE\x10\xde\x9a\x46\x12\x31\n+NIDCPOWER_ATTRIBUTE_APERTURE_TIME_AUTO_MODE\x10\xea\x9a\x46\x12/\n)NIDCPOWER_ATTRIBUTE_LCR_SOURCE_DELAY_MODE\x10\xeb\x9a\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_LCR_LOAD_RESISTANCE\x10\xee\x9a\x46\x12-\n\'NIDCPOWER_ATTRIBUTE_LCR_LOAD_INDUCTANCE\x10\xef\x9a\x46\x12.\n(NIDCPOWER_ATTRIBUTE_LCR_LOAD_CAPACITANCE\x10\xf0\x9a\x46\x12\x34\n.NIDCPOWER_ATTRIBUTE_LCR_IMPEDANCE_RANGE_SOURCE\x10\xf1\x9a\x46\x12\x44\n>NIDCPOWER_ATTRIBUTE_AUTORANGE_MAXIMUM_DELAY_AFTER_RANGE_CHANGE\x10\xf2\x9a\x46\x12\'\n!NIDCPOWER_ATTRIBUTE_VOLTAGE_LEVEL\x10\xd1\xa5L\x12%\n\x1fNIDCPOWER_ATTRIBUTE_OVP_ENABLED\x10\xd2\xa5L\x12#\n\x1dNIDCPOWER_ATTRIBUTE_OVP_LIMIT\x10\xd3\xa5L\x12\x30\n*NIDCPOWER_ATTRIBUTE_CURRENT_LIMIT_BEHAVIOR\x10\xd4\xa5L\x12\'\n!NIDCPOWER_ATTRIBUTE_CURRENT_LIMIT\x10\xd5\xa5L\x12(\n\"NIDCPOWER_ATTRIBUTE_OUTPUT_ENABLED\x10\xd6\xa5L*\xa2\x01\n\x11\x41pertureTimeUnits\x12#\n\x1f\x41PERTURE_TIME_UNITS_UNSPECIFIED\x10\x00\x12.\n)APERTURE_TIME_UNITS_NIDCPOWER_VAL_SECONDS\x10\x84\x08\x12\x38\n3APERTURE_TIME_UNITS_NIDCPOWER_VAL_POWER_LINE_CYCLES\x10\x85\x08*n\n\x08\x41utoZero\x12\x1f\n\x1b\x41UTO_ZERO_NIDCPOWER_VAL_OFF\x10\x00\x12\x1e\n\x1a\x41UTO_ZERO_NIDCPOWER_VAL_ON\x10\x01\x12!\n\x1c\x41UTO_ZERO_NIDCPOWER_VAL_ONCE\x10\x80\x08*\x88\x01\n\x14\x43urrentLimitBehavior\x12\x39\n5CURRENT_LIMIT_BEHAVIOR_NIDCPOWER_VAL_CURRENT_REGULATE\x10\x00\x12\x35\n1CURRENT_LIMIT_BEHAVIOR_NIDCPOWER_VAL_CURRENT_TRIP\x10\x01*|\n\x0b\x44igitalEdge\x12\x1c\n\x18\x44IGITAL_EDGE_UNSPECIFIED\x10\x00\x12&\n!DIGITAL_EDGE_NIDCPOWER_VAL_RISING\x10\xf8\x07\x12\'\n\"DIGITAL_EDGE_NIDCPOWER_VAL_FALLING\x10\xf9\x07*\xb3\x02\n\x05\x45vent\x12\x15\n\x11\x45VENT_UNSPECIFIED\x10\x00\x12(\n#EVENT_NIDCPOWER_VAL_SOURCE_COMPLETE\x10\x86\x08\x12)\n$EVENT_NIDCPOWER_VAL_MEASURE_COMPLETE\x10\x87\x08\x12\x34\n/EVENT_NIDCPOWER_VAL_SEQUENCE_ITERATION_COMPLETE\x10\x88\x08\x12-\n(EVENT_NIDCPOWER_VAL_SEQUENCE_ENGINE_DONE\x10\x89\x08\x12\'\n\"EVENT_NIDCPOWER_VAL_PULSE_COMPLETE\x10\x9b\x08\x12\x30\n+EVENT_NIDCPOWER_VAL_READY_FOR_PULSE_TRIGGER\x10\x9c\x08*\xc7\x05\n\x0c\x45xportSignal\x12\x1d\n\x19\x45XPORT_SIGNAL_UNSPECIFIED\x10\x00\x12\x36\n1EXPORT_SIGNAL_NIDCPOWER_VAL_SOURCE_COMPLETE_EVENT\x10\x86\x08\x12\x37\n2EXPORT_SIGNAL_NIDCPOWER_VAL_MEASURE_COMPLETE_EVENT\x10\x87\x08\x12\x42\n=EXPORT_SIGNAL_NIDCPOWER_VAL_SEQUENCE_ITERATION_COMPLETE_EVENT\x10\x88\x08\x12;\n6EXPORT_SIGNAL_NIDCPOWER_VAL_SEQUENCE_ENGINE_DONE_EVENT\x10\x89\x08\x12\x35\n0EXPORT_SIGNAL_NIDCPOWER_VAL_PULSE_COMPLETE_EVENT\x10\x9b\x08\x12>\n9EXPORT_SIGNAL_NIDCPOWER_VAL_READY_FOR_PULSE_TRIGGER_EVENT\x10\x9c\x08\x12.\n)EXPORT_SIGNAL_NIDCPOWER_VAL_START_TRIGGER\x10\x8a\x08\x12/\n*EXPORT_SIGNAL_NIDCPOWER_VAL_SOURCE_TRIGGER\x10\x8b\x08\x12\x30\n+EXPORT_SIGNAL_NIDCPOWER_VAL_MEASURE_TRIGGER\x10\x8c\x08\x12\x39\n4EXPORT_SIGNAL_NIDCPOWER_VAL_SEQUENCE_ADVANCE_TRIGGER\x10\x8d\x08\x12.\n)EXPORT_SIGNAL_NIDCPOWER_VAL_PULSE_TRIGGER\x10\x9d\x08\x12\x31\n,EXPORT_SIGNAL_NIDCPOWER_VAL_SHUTDOWN_TRIGGER\x10\xde\x08*\x84\x03\n\x13LCRCompensationType\x12%\n!LCR_COMPENSATION_TYPE_UNSPECIFIED\x10\x00\x12:\n5LCR_COMPENSATION_TYPE_NIDCPOWER_VAL_OPEN_COMPENSATION\x10\xea\x08\x12;\n6LCR_COMPENSATION_TYPE_NIDCPOWER_VAL_SHORT_COMPENSATION\x10\xeb\x08\x12:\n5LCR_COMPENSATION_TYPE_NIDCPOWER_VAL_LOAD_COMPENSATION\x10\xec\x08\x12G\nBLCR_COMPENSATION_TYPE_NIDCPOWER_VAL_OPEN_CUSTOM_CABLE_COMPENSATION\x10\xed\x08\x12H\nCLCR_COMPENSATION_TYPE_NIDCPOWER_VAL_SHORT_CUSTOM_CABLE_COMPENSATION\x10\xee\x08*|\n\x10MeasurementTypes\x12\x33\n/MEASUREMENT_TYPES_NIDCPOWER_VAL_MEASURE_CURRENT\x10\x00\x12\x33\n/MEASUREMENT_TYPES_NIDCPOWER_VAL_MEASURE_VOLTAGE\x10\x01*\xf9+\n\x1dNiDCPowerInt32AttributeValues\x12\x1f\n\x1bNIDCPOWER_INT32_UNSPECIFIED\x10\x00\x12L\nGNIDCPOWER_INT32_APERTURE_TIME_AUTO_MODE_VAL_APERTURE_TIME_AUTO_MODE_OFF\x10\xef\x08\x12N\nINIDCPOWER_INT32_APERTURE_TIME_AUTO_MODE_VAL_APERTURE_TIME_AUTO_MODE_SHORT\x10\xf0\x08\x12O\nJNIDCPOWER_INT32_APERTURE_TIME_AUTO_MODE_VAL_APERTURE_TIME_AUTO_MODE_NORMAL\x10\xf1\x08\x12M\nHNIDCPOWER_INT32_APERTURE_TIME_AUTO_MODE_VAL_APERTURE_TIME_AUTO_MODE_LONG\x10\xf2\x08\x12\x34\n/NIDCPOWER_INT32_APERTURE_TIME_UNITS_VAL_SECONDS\x10\x84\x08\x12>\n9NIDCPOWER_INT32_APERTURE_TIME_UNITS_VAL_POWER_LINE_CYCLES\x10\x85\x08\x12%\n!NIDCPOWER_INT32_AUTO_ZERO_VAL_OFF\x10\x00\x12$\n NIDCPOWER_INT32_AUTO_ZERO_VAL_ON\x10\x01\x12\'\n\"NIDCPOWER_INT32_AUTO_ZERO_VAL_ONCE\x10\x80\x08\x12H\nCNIDCPOWER_INT32_AUTORANGE_APERTURE_TIME_MODE_VAL_APERTURE_TIME_AUTO\x10\xd6\x08\x12J\nENIDCPOWER_INT32_AUTORANGE_APERTURE_TIME_MODE_VAL_APERTURE_TIME_CUSTOM\x10\xd7\x08\x12G\nBNIDCPOWER_INT32_AUTORANGE_BEHAVIOR_VAL_RANGE_UP_TO_LIMIT_THEN_DOWN\x10\xd3\x08\x12\x34\n/NIDCPOWER_INT32_AUTORANGE_BEHAVIOR_VAL_RANGE_UP\x10\xd4\x08\x12=\n8NIDCPOWER_INT32_AUTORANGE_BEHAVIOR_VAL_RANGE_UP_AND_DOWN\x10\xd5\x08\x12G\nBNIDCPOWER_INT32_AUTORANGE_THRESHOLD_MODE_VAL_THRESHOLD_MODE_NORMAL\x10\xd8\x08\x12J\nENIDCPOWER_INT32_AUTORANGE_THRESHOLD_MODE_VAL_THRESHOLD_MODE_FAST_STEP\x10\xd9\x08\x12P\nKNIDCPOWER_INT32_AUTORANGE_THRESHOLD_MODE_VAL_THRESHOLD_MODE_HIGH_HYSTERESIS\x10\xda\x08\x12R\nMNIDCPOWER_INT32_AUTORANGE_THRESHOLD_MODE_VAL_THRESHOLD_MODE_MEDIUM_HYSTERESIS\x10\xdb\x08\x12\x45\n@NIDCPOWER_INT32_AUTORANGE_THRESHOLD_MODE_VAL_THRESHOLD_MODE_HOLD\x10\xdc\x08\x12,\n\'NIDCPOWER_INT32_CABLE_LENGTH_VAL_ZERO_M\x10\xe1\x08\x12\x34\n/NIDCPOWER_INT32_CABLE_LENGTH_VAL_NI_STANDARD_1M\x10\xe2\x08\x12\x34\n/NIDCPOWER_INT32_CABLE_LENGTH_VAL_NI_STANDARD_2M\x10\xe3\x08\x12\x34\n/NIDCPOWER_INT32_CABLE_LENGTH_VAL_NI_STANDARD_4M\x10\xe4\x08\x12<\n7NIDCPOWER_INT32_CABLE_LENGTH_VAL_CUSTOM_ONBOARD_STORAGE\x10\xe5\x08\x12:\n5NIDCPOWER_INT32_CABLE_LENGTH_VAL_CUSTOM_AS_CONFIGURED\x10\xe6\x08\x12=\n8NIDCPOWER_INT32_CABLE_LENGTH_VAL_NI_STANDARD_TRIAXIAL_1M\x10\xf3\x08\x12=\n8NIDCPOWER_INT32_CABLE_LENGTH_VAL_NI_STANDARD_TRIAXIAL_2M\x10\xf4\x08\x12=\n8NIDCPOWER_INT32_CABLE_LENGTH_VAL_NI_STANDARD_TRIAXIAL_4M\x10\xf5\x08\x12;\n7NIDCPOWER_INT32_COMPLIANCE_LIMIT_SYMMETRY_VAL_SYMMETRIC\x10\x00\x12<\n8NIDCPOWER_INT32_COMPLIANCE_LIMIT_SYMMETRY_VAL_ASYMMETRIC\x10\x01\x12?\n;NIDCPOWER_INT32_CURRENT_LIMIT_BEHAVIOR_VAL_CURRENT_REGULATE\x10\x00\x12;\n7NIDCPOWER_INT32_CURRENT_LIMIT_BEHAVIOR_VAL_CURRENT_TRIP\x10\x01\x12K\nFNIDCPOWER_INT32_DC_NOISE_REJECTION_VAL_DC_NOISE_REJECTION_SECOND_ORDER\x10\x93\x08\x12\x45\n@NIDCPOWER_INT32_DC_NOISE_REJECTION_VAL_DC_NOISE_REJECTION_NORMAL\x10\x94\x08\x12,\n\'NIDCPOWER_INT32_DIGITAL_EDGE_VAL_RISING\x10\xf8\x07\x12-\n(NIDCPOWER_INT32_DIGITAL_EDGE_VAL_FALLING\x10\xf9\x07\x12/\n*NIDCPOWER_INT32_INSTRUMENT_MODE_VAL_SMU_PS\x10\xa5\x08\x12,\n\'NIDCPOWER_INT32_INSTRUMENT_MODE_VAL_LCR\x10\xa6\x08\x12\x31\n,NIDCPOWER_INT32_ISOLATION_STATE_VAL_ISOLATED\x10\xe8\x08\x12\x35\n0NIDCPOWER_INT32_ISOLATION_STATE_VAL_NON_ISOLATED\x10\xe9\x08\x12\x37\n3NIDCPOWER_INT32_LCR_AUTOMATIC_LEVEL_CONTROL_VAL_OFF\x10\x00\x12\x36\n2NIDCPOWER_INT32_LCR_AUTOMATIC_LEVEL_CONTROL_VAL_ON\x10\x01\x12\x36\n1NIDCPOWER_INT32_LCRDC_BIAS_SOURCE_VAL_DC_BIAS_OFF\x10\xa9\x08\x12:\n5NIDCPOWER_INT32_LCRDC_BIAS_SOURCE_VAL_DC_BIAS_VOLTAGE\x10\xaa\x08\x12:\n5NIDCPOWER_INT32_LCRDC_BIAS_SOURCE_VAL_DC_BIAS_CURRENT\x10\xab\x08\x12@\n;NIDCPOWER_INT32_LCR_IMPEDANCE_AUTO_RANGE_VAL_AUTO_RANGE_OFF\x10\xac\x08\x12?\n:NIDCPOWER_INT32_LCR_IMPEDANCE_AUTO_RANGE_VAL_AUTO_RANGE_ON\x10\xae\x08\x12G\nBNIDCPOWER_INT32_LCR_IMPEDANCE_RANGE_SOURCE_VAL_LCR_IMPEDANCE_RANGE\x10\xf6\x08\x12J\nENIDCPOWER_INT32_LCR_IMPEDANCE_RANGE_SOURCE_VAL_LCR_LOAD_CONFIGURATION\x10\xf7\x08\x12\x44\n?NIDCPOWER_INT32_LCR_MEASUREMENT_TIME_VAL_MEASUREMENT_TIME_SHORT\x10\xaf\x08\x12\x45\n@NIDCPOWER_INT32_LCR_MEASUREMENT_TIME_VAL_MEASUREMENT_TIME_MEDIUM\x10\xb0\x08\x12\x43\n>NIDCPOWER_INT32_LCR_MEASUREMENT_TIME_VAL_MEASUREMENT_TIME_LONG\x10\xb1\x08\x12\x45\n@NIDCPOWER_INT32_LCR_MEASUREMENT_TIME_VAL_MEASUREMENT_TIME_CUSTOM\x10\xdd\x08\x12U\nPNIDCPOWER_INT32_LCR_OPEN_SHORT_LOAD_COMPENSATION_DATA_SOURCE_VAL_ONBOARD_STORAGE\x10\xb2\x08\x12P\nKNIDCPOWER_INT32_LCR_OPEN_SHORT_LOAD_COMPENSATION_DATA_SOURCE_VAL_AS_DEFINED\x10\xb3\x08\x12S\nNNIDCPOWER_INT32_LCR_OPEN_SHORT_LOAD_COMPENSATION_DATA_SOURCE_VAL_AS_CONFIGURED\x10\xfa\x08\x12N\nINIDCPOWER_INT32_LCR_SOURCE_DELAY_MODE_VAL_LCR_SOURCE_DELAY_MODE_AUTOMATIC\x10\xf8\x08\x12K\nFNIDCPOWER_INT32_LCR_SOURCE_DELAY_MODE_VAL_LCR_SOURCE_DELAY_MODE_MANUAL\x10\xf9\x08\x12\x39\n4NIDCPOWER_INT32_LCR_STIMULUS_FUNCTION_VAL_AC_VOLTAGE\x10\xa7\x08\x12\x39\n4NIDCPOWER_INT32_LCR_STIMULUS_FUNCTION_VAL_AC_CURRENT\x10\xa8\x08\x12I\nDNIDCPOWER_INT32_MEASURE_WHEN_VAL_AUTOMATICALLY_AFTER_SOURCE_COMPLETE\x10\x81\x08\x12/\n*NIDCPOWER_INT32_MEASURE_WHEN_VAL_ON_DEMAND\x10\x82\x08\x12\x38\n3NIDCPOWER_INT32_MEASURE_WHEN_VAL_ON_MEASURE_TRIGGER\x10\x83\x08\x12/\n*NIDCPOWER_INT32_OUTPUT_CAPACITANCE_VAL_LOW\x10\xf2\x07\x12\x30\n+NIDCPOWER_INT32_OUTPUT_CAPACITANCE_VAL_HIGH\x10\xf3\x07\x12\x33\n.NIDCPOWER_INT32_OUTPUT_FUNCTION_VAL_DC_VOLTAGE\x10\xee\x07\x12\x33\n.NIDCPOWER_INT32_OUTPUT_FUNCTION_VAL_DC_CURRENT\x10\xef\x07\x12\x36\n1NIDCPOWER_INT32_OUTPUT_FUNCTION_VAL_PULSE_VOLTAGE\x10\x99\x08\x12\x36\n1NIDCPOWER_INT32_OUTPUT_FUNCTION_VAL_PULSE_CURRENT\x10\x9a\x08\x12-\n(NIDCPOWER_INT32_POLARITY_VAL_ACTIVE_HIGH\x10\xfa\x07\x12,\n\'NIDCPOWER_INT32_POLARITY_VAL_ACTIVE_LOW\x10\xfb\x07\x12\x37\n2NIDCPOWER_INT32_POWER_ALLOCATION_MODE_VAL_DISABLED\x10\xa2\x08\x12\x38\n3NIDCPOWER_INT32_POWER_ALLOCATION_MODE_VAL_AUTOMATIC\x10\xa3\x08\x12\x35\n0NIDCPOWER_INT32_POWER_ALLOCATION_MODE_VAL_MANUAL\x10\xa4\x08\x12.\n)NIDCPOWER_INT32_POWER_SOURCE_VAL_INTERNAL\x10\xeb\x07\x12/\n*NIDCPOWER_INT32_POWER_SOURCE_VAL_AUXILIARY\x10\xec\x07\x12/\n*NIDCPOWER_INT32_POWER_SOURCE_VAL_AUTOMATIC\x10\xed\x07\x12\x35\n0NIDCPOWER_INT32_POWER_SOURCE_IN_USE_VAL_INTERNAL\x10\xeb\x07\x12\x36\n1NIDCPOWER_INT32_POWER_SOURCE_IN_USE_VAL_AUXILIARY\x10\xec\x07\x12\x44\n?NIDCPOWER_INT32_SELF_CALIBRATION_PERSISTENCE_VAL_KEEP_IN_MEMORY\x10\x95\x08\x12\x45\n@NIDCPOWER_INT32_SELF_CALIBRATION_PERSISTENCE_VAL_WRITE_TO_EEPROM\x10\x96\x08\x12$\n\x1fNIDCPOWER_INT32_SENSE_VAL_LOCAL\x10\xf0\x07\x12%\n NIDCPOWER_INT32_SENSE_VAL_REMOTE\x10\xf1\x07\x12\x31\n,NIDCPOWER_INT32_SOURCE_MODE_VAL_SINGLE_POINT\x10\xfc\x07\x12-\n(NIDCPOWER_INT32_SOURCE_MODE_VAL_SEQUENCE\x10\xfd\x07\x12\x32\n-NIDCPOWER_INT32_TRANSIENT_RESPONSE_VAL_NORMAL\x10\x8e\x08\x12\x30\n+NIDCPOWER_INT32_TRANSIENT_RESPONSE_VAL_FAST\x10\x8f\x08\x12\x30\n+NIDCPOWER_INT32_TRANSIENT_RESPONSE_VAL_SLOW\x10\x91\x08\x12\x32\n-NIDCPOWER_INT32_TRANSIENT_RESPONSE_VAL_CUSTOM\x10\x92\x08\x12*\n%NIDCPOWER_INT32_TRIGGER_TYPE_VAL_NONE\x10\xf4\x07\x12\x32\n-NIDCPOWER_INT32_TRIGGER_TYPE_VAL_DIGITAL_EDGE\x10\xf6\x07\x12\x33\n.NIDCPOWER_INT32_TRIGGER_TYPE_VAL_SOFTWARE_EDGE\x10\xf7\x07\x1a\x02\x10\x01*\xb6\x01\n\x1eNiDCPowerReal64AttributeValues\x12 \n\x1cNIDCPOWER_REAL64_UNSPECIFIED\x10\x00\x12\x38\n4NIDCPOWER_REAL64_POWER_LINE_FREQUENCIES_VAL_50_HERTZ\x10\x32\x12\x38\n4NIDCPOWER_REAL64_POWER_LINE_FREQUENCIES_VAL_60_HERTZ\x10<*\x8b\x06\n\x12OutputCutoffReason\x12$\n OUTPUT_CUTOFF_REASON_UNSPECIFIED\x10\x00\x12H\n;OUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_ALL\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12O\nKOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_VOLTAGE_OUTPUT_HIGH\x10\x01\x12N\nJOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_VOLTAGE_OUTPUT_LOW\x10\x02\x12P\nLOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_CURRENT_MEASURE_HIGH\x10\x04\x12O\nKOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_CURRENT_MEASURE_LOW\x10\x08\x12O\nKOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_VOLTAGE_CHANGE_HIGH\x10\x10\x12N\nJOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_VOLTAGE_CHANGE_LOW\x10 \x12O\nKOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_CURRENT_CHANGE_HIGH\x10@\x12O\nJOUTPUT_CUTOFF_REASON_NIDCPOWER_VAL_OUTPUT_CUTOFF_REASON_CURRENT_CHANGE_LOW\x10\x80\x01*\xf3\x01\n\x0eOutputFunction\x12\x1f\n\x1bOUTPUT_FUNCTION_UNSPECIFIED\x10\x00\x12-\n(OUTPUT_FUNCTION_NIDCPOWER_VAL_DC_VOLTAGE\x10\xee\x07\x12-\n(OUTPUT_FUNCTION_NIDCPOWER_VAL_DC_CURRENT\x10\xef\x07\x12\x30\n+OUTPUT_FUNCTION_NIDCPOWER_VAL_PULSE_VOLTAGE\x10\x99\x08\x12\x30\n+OUTPUT_FUNCTION_NIDCPOWER_VAL_PULSE_CURRENT\x10\x9a\x08*\x9e\x02\n\x0cOutputStates\x12\x37\n3OUTPUT_STATES_NIDCPOWER_VAL_OUTPUT_CONSTANT_VOLTAGE\x10\x00\x12\x37\n3OUTPUT_STATES_NIDCPOWER_VAL_OUTPUT_CONSTANT_CURRENT\x10\x01\x12\x33\n/OUTPUT_STATES_NIDCPOWER_VAL_OUTPUT_OVER_VOLTAGE\x10\x02\x12\x33\n/OUTPUT_STATES_NIDCPOWER_VAL_OUTPUT_OVER_CURRENT\x10\x03\x12\x32\n.OUTPUT_STATES_NIDCPOWER_VAL_OUTPUT_UNREGULATED\x10\x04*\xa4\x01\n\x14PowerLineFrequencies\x12&\n\"POWER_LINE_FREQUENCIES_UNSPECIFIED\x10\x00\x12\x31\n-POWER_LINE_FREQUENCIES_NIDCPOWER_VAL_50_HERTZ\x10\x32\x12\x31\n-POWER_LINE_FREQUENCIES_NIDCPOWER_VAL_60_HERTZ\x10<*\xbb\x03\n\x1bSendSoftwareEdgeTriggerType\x12/\n+SEND_SOFTWARE_EDGE_TRIGGER_TYPE_UNSPECIFIED\x10\x00\x12\x38\n3SEND_SOFTWARE_EDGE_TRIGGER_TYPE_NIDCPOWER_VAL_START\x10\x8a\x08\x12\x39\n4SEND_SOFTWARE_EDGE_TRIGGER_TYPE_NIDCPOWER_VAL_SOURCE\x10\x8b\x08\x12:\n5SEND_SOFTWARE_EDGE_TRIGGER_TYPE_NIDCPOWER_VAL_MEASURE\x10\x8c\x08\x12\x43\n>SEND_SOFTWARE_EDGE_TRIGGER_TYPE_NIDCPOWER_VAL_SEQUENCE_ADVANCE\x10\x8d\x08\x12\x38\n3SEND_SOFTWARE_EDGE_TRIGGER_TYPE_NIDCPOWER_VAL_PULSE\x10\x9d\x08\x12;\n6SEND_SOFTWARE_EDGE_TRIGGER_TYPE_NIDCPOWER_VAL_SHUTDOWN\x10\xde\x08*_\n\x05Sense\x12\x15\n\x11SENSE_UNSPECIFIED\x10\x00\x12\x1e\n\x19SENSE_NIDCPOWER_VAL_LOCAL\x10\xf0\x07\x12\x1f\n\x1aSENSE_NIDCPOWER_VAL_REMOTE\x10\xf1\x07*\x7f\n\nSourceMode\x12\x1b\n\x17SOURCE_MODE_UNSPECIFIED\x10\x00\x12+\n&SOURCE_MODE_NIDCPOWER_VAL_SINGLE_POINT\x10\xfc\x07\x12\'\n\"SOURCE_MODE_NIDCPOWER_VAL_SEQUENCE\x10\xfd\x07\x32\x9f\x95\x01\n\tNiDCPower\x12\x44\n\x05\x41\x62ort\x12\x1c.nidcpower_grpc.AbortRequest\x1a\x1d.nidcpower_grpc.AbortResponse\x12h\n\x11\x41\x62ortWithChannels\x12(.nidcpower_grpc.AbortWithChannelsRequest\x1a).nidcpower_grpc.AbortWithChannelsResponse\x12\x65\n\x10\x43\x61lSelfCalibrate\x12\'.nidcpower_grpc.CalSelfCalibrateRequest\x1a(.nidcpower_grpc.CalSelfCalibrateResponse\x12S\n\nClearError\x12!.nidcpower_grpc.ClearErrorRequest\x1a\".nidcpower_grpc.ClearErrorResponse\x12}\n\x18\x43learInterchangeWarnings\x12/.nidcpower_grpc.ClearInterchangeWarningsRequest\x1a\x30.nidcpower_grpc.ClearInterchangeWarningsResponse\x12\x8c\x01\n\x1d\x43learLatchedOutputCutoffState\x12\x34.nidcpower_grpc.ClearLatchedOutputCutoffStateRequest\x1a\x35.nidcpower_grpc.ClearLatchedOutputCutoffStateResponse\x12\x44\n\x05\x43lose\x12\x1c.nidcpower_grpc.CloseRequest\x1a\x1d.nidcpower_grpc.CloseResponse\x12G\n\x06\x43ommit\x12\x1d.nidcpower_grpc.CommitRequest\x1a\x1e.nidcpower_grpc.CommitResponse\x12k\n\x12\x43ommitWithChannels\x12).nidcpower_grpc.CommitWithChannelsRequest\x1a*.nidcpower_grpc.CommitWithChannelsResponse\x12t\n\x15\x43onfigureApertureTime\x12,.nidcpower_grpc.ConfigureApertureTimeRequest\x1a-.nidcpower_grpc.ConfigureApertureTimeResponse\x12h\n\x11\x43onfigureAutoZero\x12(.nidcpower_grpc.ConfigureAutoZeroRequest\x1a).nidcpower_grpc.ConfigureAutoZeroResponse\x12t\n\x15\x43onfigureCurrentLevel\x12,.nidcpower_grpc.ConfigureCurrentLevelRequest\x1a-.nidcpower_grpc.ConfigureCurrentLevelResponse\x12\x83\x01\n\x1a\x43onfigureCurrentLevelRange\x12\x31.nidcpower_grpc.ConfigureCurrentLevelRangeRequest\x1a\x32.nidcpower_grpc.ConfigureCurrentLevelRangeResponse\x12t\n\x15\x43onfigureCurrentLimit\x12,.nidcpower_grpc.ConfigureCurrentLimitRequest\x1a-.nidcpower_grpc.ConfigureCurrentLimitResponse\x12\x83\x01\n\x1a\x43onfigureCurrentLimitRange\x12\x31.nidcpower_grpc.ConfigureCurrentLimitRangeRequest\x1a\x32.nidcpower_grpc.ConfigureCurrentLimitRangeResponse\x12\x9b\x01\n\"ConfigureDigitalEdgeMeasureTrigger\x12\x39.nidcpower_grpc.ConfigureDigitalEdgeMeasureTriggerRequest\x1a:.nidcpower_grpc.ConfigureDigitalEdgeMeasureTriggerResponse\x12\xbf\x01\n.ConfigureDigitalEdgeMeasureTriggerWithChannels\x12\x45.nidcpower_grpc.ConfigureDigitalEdgeMeasureTriggerWithChannelsRequest\x1a\x46.nidcpower_grpc.ConfigureDigitalEdgeMeasureTriggerWithChannelsResponse\x12\x95\x01\n ConfigureDigitalEdgePulseTrigger\x12\x37.nidcpower_grpc.ConfigureDigitalEdgePulseTriggerRequest\x1a\x38.nidcpower_grpc.ConfigureDigitalEdgePulseTriggerResponse\x12\xb9\x01\n,ConfigureDigitalEdgePulseTriggerWithChannels\x12\x43.nidcpower_grpc.ConfigureDigitalEdgePulseTriggerWithChannelsRequest\x1a\x44.nidcpower_grpc.ConfigureDigitalEdgePulseTriggerWithChannelsResponse\x12\xb3\x01\n*ConfigureDigitalEdgeSequenceAdvanceTrigger\x12\x41.nidcpower_grpc.ConfigureDigitalEdgeSequenceAdvanceTriggerRequest\x1a\x42.nidcpower_grpc.ConfigureDigitalEdgeSequenceAdvanceTriggerResponse\x12\xd7\x01\n6ConfigureDigitalEdgeSequenceAdvanceTriggerWithChannels\x12M.nidcpower_grpc.ConfigureDigitalEdgeSequenceAdvanceTriggerWithChannelsRequest\x1aN.nidcpower_grpc.ConfigureDigitalEdgeSequenceAdvanceTriggerWithChannelsResponse\x12\xc2\x01\n/ConfigureDigitalEdgeShutdownTriggerWithChannels\x12\x46.nidcpower_grpc.ConfigureDigitalEdgeShutdownTriggerWithChannelsRequest\x1aG.nidcpower_grpc.ConfigureDigitalEdgeShutdownTriggerWithChannelsResponse\x12\x98\x01\n!ConfigureDigitalEdgeSourceTrigger\x12\x38.nidcpower_grpc.ConfigureDigitalEdgeSourceTriggerRequest\x1a\x39.nidcpower_grpc.ConfigureDigitalEdgeSourceTriggerResponse\x12\xbc\x01\n-ConfigureDigitalEdgeSourceTriggerWithChannels\x12\x44.nidcpower_grpc.ConfigureDigitalEdgeSourceTriggerWithChannelsRequest\x1a\x45.nidcpower_grpc.ConfigureDigitalEdgeSourceTriggerWithChannelsResponse\x12\x95\x01\n ConfigureDigitalEdgeStartTrigger\x12\x37.nidcpower_grpc.ConfigureDigitalEdgeStartTriggerRequest\x1a\x38.nidcpower_grpc.ConfigureDigitalEdgeStartTriggerResponse\x12\xb9\x01\n,ConfigureDigitalEdgeStartTriggerWithChannels\x12\x43.nidcpower_grpc.ConfigureDigitalEdgeStartTriggerWithChannelsRequest\x1a\x44.nidcpower_grpc.ConfigureDigitalEdgeStartTriggerWithChannelsResponse\x12\x9e\x01\n#ConfigureLCRCustomCableCompensation\x12:.nidcpower_grpc.ConfigureLCRCustomCableCompensationRequest\x1a;.nidcpower_grpc.ConfigureLCRCustomCableCompensationResponse\x12w\n\x16\x43onfigureOutputEnabled\x12-.nidcpower_grpc.ConfigureOutputEnabledRequest\x1a..nidcpower_grpc.ConfigureOutputEnabledResponse\x12z\n\x17\x43onfigureOutputFunction\x12..nidcpower_grpc.ConfigureOutputFunctionRequest\x1a/.nidcpower_grpc.ConfigureOutputFunctionResponse\x12\x80\x01\n\x19\x43onfigureOutputResistance\x12\x30.nidcpower_grpc.ConfigureOutputResistanceRequest\x1a\x31.nidcpower_grpc.ConfigureOutputResistanceResponse\x12Y\n\x0c\x43onfigureOvp\x12#.nidcpower_grpc.ConfigureOvpRequest\x1a$.nidcpower_grpc.ConfigureOvpResponse\x12\x86\x01\n\x1b\x43onfigurePowerLineFrequency\x12\x32.nidcpower_grpc.ConfigurePowerLineFrequencyRequest\x1a\x33.nidcpower_grpc.ConfigurePowerLineFrequencyResponse\x12\x8f\x01\n\x1e\x43onfigurePulseBiasCurrentLevel\x12\x35.nidcpower_grpc.ConfigurePulseBiasCurrentLevelRequest\x1a\x36.nidcpower_grpc.ConfigurePulseBiasCurrentLevelResponse\x12\x8f\x01\n\x1e\x43onfigurePulseBiasCurrentLimit\x12\x35.nidcpower_grpc.ConfigurePulseBiasCurrentLimitRequest\x1a\x36.nidcpower_grpc.ConfigurePulseBiasCurrentLimitResponse\x12\x8f\x01\n\x1e\x43onfigurePulseBiasVoltageLevel\x12\x35.nidcpower_grpc.ConfigurePulseBiasVoltageLevelRequest\x1a\x36.nidcpower_grpc.ConfigurePulseBiasVoltageLevelResponse\x12\x8f\x01\n\x1e\x43onfigurePulseBiasVoltageLimit\x12\x35.nidcpower_grpc.ConfigurePulseBiasVoltageLimitRequest\x1a\x36.nidcpower_grpc.ConfigurePulseBiasVoltageLimitResponse\x12\x83\x01\n\x1a\x43onfigurePulseCurrentLevel\x12\x31.nidcpower_grpc.ConfigurePulseCurrentLevelRequest\x1a\x32.nidcpower_grpc.ConfigurePulseCurrentLevelResponse\x12\x92\x01\n\x1f\x43onfigurePulseCurrentLevelRange\x12\x36.nidcpower_grpc.ConfigurePulseCurrentLevelRangeRequest\x1a\x37.nidcpower_grpc.ConfigurePulseCurrentLevelRangeResponse\x12\x83\x01\n\x1a\x43onfigurePulseCurrentLimit\x12\x31.nidcpower_grpc.ConfigurePulseCurrentLimitRequest\x1a\x32.nidcpower_grpc.ConfigurePulseCurrentLimitResponse\x12\x92\x01\n\x1f\x43onfigurePulseCurrentLimitRange\x12\x36.nidcpower_grpc.ConfigurePulseCurrentLimitRangeRequest\x1a\x37.nidcpower_grpc.ConfigurePulseCurrentLimitRangeResponse\x12\x83\x01\n\x1a\x43onfigurePulseVoltageLevel\x12\x31.nidcpower_grpc.ConfigurePulseVoltageLevelRequest\x1a\x32.nidcpower_grpc.ConfigurePulseVoltageLevelResponse\x12\x92\x01\n\x1f\x43onfigurePulseVoltageLevelRange\x12\x36.nidcpower_grpc.ConfigurePulseVoltageLevelRangeRequest\x1a\x37.nidcpower_grpc.ConfigurePulseVoltageLevelRangeResponse\x12\x83\x01\n\x1a\x43onfigurePulseVoltageLimit\x12\x31.nidcpower_grpc.ConfigurePulseVoltageLimitRequest\x1a\x32.nidcpower_grpc.ConfigurePulseVoltageLimitResponse\x12\x92\x01\n\x1f\x43onfigurePulseVoltageLimitRange\x12\x36.nidcpower_grpc.ConfigurePulseVoltageLimitRangeRequest\x1a\x37.nidcpower_grpc.ConfigurePulseVoltageLimitRangeResponse\x12_\n\x0e\x43onfigureSense\x12%.nidcpower_grpc.ConfigureSenseRequest\x1a&.nidcpower_grpc.ConfigureSenseResponse\x12\x9e\x01\n#ConfigureSoftwareEdgeMeasureTrigger\x12:.nidcpower_grpc.ConfigureSoftwareEdgeMeasureTriggerRequest\x1a;.nidcpower_grpc.ConfigureSoftwareEdgeMeasureTriggerResponse\x12\xc2\x01\n/ConfigureSoftwareEdgeMeasureTriggerWithChannels\x12\x46.nidcpower_grpc.ConfigureSoftwareEdgeMeasureTriggerWithChannelsRequest\x1aG.nidcpower_grpc.ConfigureSoftwareEdgeMeasureTriggerWithChannelsResponse\x12\x98\x01\n!ConfigureSoftwareEdgePulseTrigger\x12\x38.nidcpower_grpc.ConfigureSoftwareEdgePulseTriggerRequest\x1a\x39.nidcpower_grpc.ConfigureSoftwareEdgePulseTriggerResponse\x12\xbc\x01\n-ConfigureSoftwareEdgePulseTriggerWithChannels\x12\x44.nidcpower_grpc.ConfigureSoftwareEdgePulseTriggerWithChannelsRequest\x1a\x45.nidcpower_grpc.ConfigureSoftwareEdgePulseTriggerWithChannelsResponse\x12\xb6\x01\n+ConfigureSoftwareEdgeSequenceAdvanceTrigger\x12\x42.nidcpower_grpc.ConfigureSoftwareEdgeSequenceAdvanceTriggerRequest\x1a\x43.nidcpower_grpc.ConfigureSoftwareEdgeSequenceAdvanceTriggerResponse\x12\xda\x01\n7ConfigureSoftwareEdgeSequenceAdvanceTriggerWithChannels\x12N.nidcpower_grpc.ConfigureSoftwareEdgeSequenceAdvanceTriggerWithChannelsRequest\x1aO.nidcpower_grpc.ConfigureSoftwareEdgeSequenceAdvanceTriggerWithChannelsResponse\x12\xc5\x01\n0ConfigureSoftwareEdgeShutdownTriggerWithChannels\x12G.nidcpower_grpc.ConfigureSoftwareEdgeShutdownTriggerWithChannelsRequest\x1aH.nidcpower_grpc.ConfigureSoftwareEdgeShutdownTriggerWithChannelsResponse\x12\x9b\x01\n\"ConfigureSoftwareEdgeSourceTrigger\x12\x39.nidcpower_grpc.ConfigureSoftwareEdgeSourceTriggerRequest\x1a:.nidcpower_grpc.ConfigureSoftwareEdgeSourceTriggerResponse\x12\xbf\x01\n.ConfigureSoftwareEdgeSourceTriggerWithChannels\x12\x45.nidcpower_grpc.ConfigureSoftwareEdgeSourceTriggerWithChannelsRequest\x1a\x46.nidcpower_grpc.ConfigureSoftwareEdgeSourceTriggerWithChannelsResponse\x12\x98\x01\n!ConfigureSoftwareEdgeStartTrigger\x12\x38.nidcpower_grpc.ConfigureSoftwareEdgeStartTriggerRequest\x1a\x39.nidcpower_grpc.ConfigureSoftwareEdgeStartTriggerResponse\x12\xbc\x01\n-ConfigureSoftwareEdgeStartTriggerWithChannels\x12\x44.nidcpower_grpc.ConfigureSoftwareEdgeStartTriggerWithChannelsRequest\x1a\x45.nidcpower_grpc.ConfigureSoftwareEdgeStartTriggerWithChannelsResponse\x12n\n\x13\x43onfigureSourceMode\x12*.nidcpower_grpc.ConfigureSourceModeRequest\x1a+.nidcpower_grpc.ConfigureSourceModeResponse\x12\x92\x01\n\x1f\x43onfigureSourceModeWithChannels\x12\x36.nidcpower_grpc.ConfigureSourceModeWithChannelsRequest\x1a\x37.nidcpower_grpc.ConfigureSourceModeWithChannelsResponse\x12t\n\x15\x43onfigureVoltageLevel\x12,.nidcpower_grpc.ConfigureVoltageLevelRequest\x1a-.nidcpower_grpc.ConfigureVoltageLevelResponse\x12\x83\x01\n\x1a\x43onfigureVoltageLevelRange\x12\x31.nidcpower_grpc.ConfigureVoltageLevelRangeRequest\x1a\x32.nidcpower_grpc.ConfigureVoltageLevelRangeResponse\x12t\n\x15\x43onfigureVoltageLimit\x12,.nidcpower_grpc.ConfigureVoltageLimitRequest\x1a-.nidcpower_grpc.ConfigureVoltageLimitResponse\x12\x83\x01\n\x1a\x43onfigureVoltageLimitRange\x12\x31.nidcpower_grpc.ConfigureVoltageLimitRangeRequest\x1a\x32.nidcpower_grpc.ConfigureVoltageLimitRangeResponse\x12w\n\x16\x43reateAdvancedSequence\x12-.nidcpower_grpc.CreateAdvancedSequenceRequest\x1a..nidcpower_grpc.CreateAdvancedSequenceResponse\x12\xb9\x01\n,CreateAdvancedSequenceCommitStepWithChannels\x12\x43.nidcpower_grpc.CreateAdvancedSequenceCommitStepWithChannelsRequest\x1a\x44.nidcpower_grpc.CreateAdvancedSequenceCommitStepWithChannelsResponse\x12\x83\x01\n\x1a\x43reateAdvancedSequenceStep\x12\x31.nidcpower_grpc.CreateAdvancedSequenceStepRequest\x1a\x32.nidcpower_grpc.CreateAdvancedSequenceStepResponse\x12\xa7\x01\n&CreateAdvancedSequenceStepWithChannels\x12=.nidcpower_grpc.CreateAdvancedSequenceStepWithChannelsRequest\x1a>.nidcpower_grpc.CreateAdvancedSequenceStepWithChannelsResponse\x12\x9b\x01\n\"CreateAdvancedSequenceWithChannels\x12\x39.nidcpower_grpc.CreateAdvancedSequenceWithChannelsRequest\x1a:.nidcpower_grpc.CreateAdvancedSequenceWithChannelsResponse\x12w\n\x16\x44\x65leteAdvancedSequence\x12-.nidcpower_grpc.DeleteAdvancedSequenceRequest\x1a..nidcpower_grpc.DeleteAdvancedSequenceResponse\x12\x9b\x01\n\"DeleteAdvancedSequenceWithChannels\x12\x39.nidcpower_grpc.DeleteAdvancedSequenceWithChannelsRequest\x1a:.nidcpower_grpc.DeleteAdvancedSequenceWithChannelsResponse\x12J\n\x07\x44isable\x12\x1e.nidcpower_grpc.DisableRequest\x1a\x1f.nidcpower_grpc.DisableResponse\x12n\n\x13\x44isablePulseTrigger\x12*.nidcpower_grpc.DisablePulseTriggerRequest\x1a+.nidcpower_grpc.DisablePulseTriggerResponse\x12\x92\x01\n\x1f\x44isablePulseTriggerWithChannels\x12\x36.nidcpower_grpc.DisablePulseTriggerWithChannelsRequest\x1a\x37.nidcpower_grpc.DisablePulseTriggerWithChannelsResponse\x12\x8c\x01\n\x1d\x44isableSequenceAdvanceTrigger\x12\x34.nidcpower_grpc.DisableSequenceAdvanceTriggerRequest\x1a\x35.nidcpower_grpc.DisableSequenceAdvanceTriggerResponse\x12\xb0\x01\n)DisableSequenceAdvanceTriggerWithChannels\x12@.nidcpower_grpc.DisableSequenceAdvanceTriggerWithChannelsRequest\x1a\x41.nidcpower_grpc.DisableSequenceAdvanceTriggerWithChannelsResponse\x12\x9b\x01\n\"DisableShutdownTriggerWithChannels\x12\x39.nidcpower_grpc.DisableShutdownTriggerWithChannelsRequest\x1a:.nidcpower_grpc.DisableShutdownTriggerWithChannelsResponse\x12q\n\x14\x44isableSourceTrigger\x12+.nidcpower_grpc.DisableSourceTriggerRequest\x1a,.nidcpower_grpc.DisableSourceTriggerResponse\x12\x95\x01\n DisableSourceTriggerWithChannels\x12\x37.nidcpower_grpc.DisableSourceTriggerWithChannelsRequest\x1a\x38.nidcpower_grpc.DisableSourceTriggerWithChannelsResponse\x12n\n\x13\x44isableStartTrigger\x12*.nidcpower_grpc.DisableStartTriggerRequest\x1a+.nidcpower_grpc.DisableStartTriggerResponse\x12\x92\x01\n\x1f\x44isableStartTriggerWithChannels\x12\x36.nidcpower_grpc.DisableStartTriggerWithChannelsRequest\x1a\x37.nidcpower_grpc.DisableStartTriggerWithChannelsResponse\x12Y\n\x0c\x45rrorMessage\x12#.nidcpower_grpc.ErrorMessageRequest\x1a$.nidcpower_grpc.ErrorMessageResponse\x12S\n\nErrorQuery\x12!.nidcpower_grpc.ErrorQueryRequest\x1a\".nidcpower_grpc.ErrorQueryResponse\x12\x9b\x01\n\"ExportAttributeConfigurationBuffer\x12\x39.nidcpower_grpc.ExportAttributeConfigurationBufferRequest\x1a:.nidcpower_grpc.ExportAttributeConfigurationBufferResponse\x12\x95\x01\n ExportAttributeConfigurationFile\x12\x37.nidcpower_grpc.ExportAttributeConfigurationFileRequest\x1a\x38.nidcpower_grpc.ExportAttributeConfigurationFileResponse\x12Y\n\x0c\x45xportSignal\x12#.nidcpower_grpc.ExportSignalRequest\x1a$.nidcpower_grpc.ExportSignalResponse\x12}\n\x18\x45xportSignalWithChannels\x12/.nidcpower_grpc.ExportSignalWithChannelsRequest\x1a\x30.nidcpower_grpc.ExportSignalWithChannelsResponse\x12\\\n\rFetchMultiple\x12$.nidcpower_grpc.FetchMultipleRequest\x1a%.nidcpower_grpc.FetchMultipleResponse\x12\x65\n\x10\x46\x65tchMultipleLCR\x12\'.nidcpower_grpc.FetchMultipleLCRRequest\x1a(.nidcpower_grpc.FetchMultipleLCRResponse\x12t\n\x15GetAttributeViBoolean\x12,.nidcpower_grpc.GetAttributeViBooleanRequest\x1a-.nidcpower_grpc.GetAttributeViBooleanResponse\x12n\n\x13GetAttributeViInt32\x12*.nidcpower_grpc.GetAttributeViInt32Request\x1a+.nidcpower_grpc.GetAttributeViInt32Response\x12n\n\x13GetAttributeViInt64\x12*.nidcpower_grpc.GetAttributeViInt64Request\x1a+.nidcpower_grpc.GetAttributeViInt64Response\x12q\n\x14GetAttributeViReal64\x12+.nidcpower_grpc.GetAttributeViReal64Request\x1a,.nidcpower_grpc.GetAttributeViReal64Response\x12t\n\x15GetAttributeViSession\x12,.nidcpower_grpc.GetAttributeViSessionRequest\x1a-.nidcpower_grpc.GetAttributeViSessionResponse\x12q\n\x14GetAttributeViString\x12+.nidcpower_grpc.GetAttributeViStringRequest\x1a,.nidcpower_grpc.GetAttributeViStringResponse\x12_\n\x0eGetChannelName\x12%.nidcpower_grpc.GetChannelNameRequest\x1a&.nidcpower_grpc.GetChannelNameResponse\x12}\n\x18GetChannelNameFromString\x12/.nidcpower_grpc.GetChannelNameFromStringRequest\x1a\x30.nidcpower_grpc.GetChannelNameFromStringResponse\x12M\n\x08GetError\x12\x1f.nidcpower_grpc.GetErrorRequest\x1a .nidcpower_grpc.GetErrorResponse\x12}\n\x18GetExtCalLastDateAndTime\x12/.nidcpower_grpc.GetExtCalLastDateAndTimeRequest\x1a\x30.nidcpower_grpc.GetExtCalLastDateAndTimeResponse\x12h\n\x11GetExtCalLastTemp\x12(.nidcpower_grpc.GetExtCalLastTempRequest\x1a).nidcpower_grpc.GetExtCalLastTempResponse\x12\x89\x01\n\x1cGetExtCalRecommendedInterval\x12\x33.nidcpower_grpc.GetExtCalRecommendedIntervalRequest\x1a\x34.nidcpower_grpc.GetExtCalRecommendedIntervalResponse\x12\x98\x01\n!GetLCRCompensationLastDateAndTime\x12\x38.nidcpower_grpc.GetLCRCompensationLastDateAndTimeRequest\x1a\x39.nidcpower_grpc.GetLCRCompensationLastDateAndTimeResponse\x12\x98\x01\n!GetLCRCustomCableCompensationData\x12\x38.nidcpower_grpc.GetLCRCustomCableCompensationDataRequest\x1a\x39.nidcpower_grpc.GetLCRCustomCableCompensationDataResponse\x12t\n\x15GetNextCoercionRecord\x12,.nidcpower_grpc.GetNextCoercionRecordRequest\x1a-.nidcpower_grpc.GetNextCoercionRecordResponse\x12\x80\x01\n\x19GetNextInterchangeWarning\x12\x30.nidcpower_grpc.GetNextInterchangeWarningRequest\x1a\x31.nidcpower_grpc.GetNextInterchangeWarningResponse\x12\x80\x01\n\x19GetSelfCalLastDateAndTime\x12\x30.nidcpower_grpc.GetSelfCalLastDateAndTimeRequest\x1a\x31.nidcpower_grpc.GetSelfCalLastDateAndTimeResponse\x12k\n\x12GetSelfCalLastTemp\x12).nidcpower_grpc.GetSelfCalLastTempRequest\x1a*.nidcpower_grpc.GetSelfCalLastTempResponse\x12\x9b\x01\n\"ImportAttributeConfigurationBuffer\x12\x39.nidcpower_grpc.ImportAttributeConfigurationBufferRequest\x1a:.nidcpower_grpc.ImportAttributeConfigurationBufferResponse\x12\x95\x01\n ImportAttributeConfigurationFile\x12\x37.nidcpower_grpc.ImportAttributeConfigurationFileRequest\x1a\x38.nidcpower_grpc.ImportAttributeConfigurationFileResponse\x12w\n\x16InitializeWithChannels\x12-.nidcpower_grpc.InitializeWithChannelsRequest\x1a..nidcpower_grpc.InitializeWithChannelsResponse\x12\x98\x01\n!InitializeWithIndependentChannels\x12\x38.nidcpower_grpc.InitializeWithIndependentChannelsRequest\x1a\x39.nidcpower_grpc.InitializeWithIndependentChannelsResponse\x12M\n\x08Initiate\x12\x1f.nidcpower_grpc.InitiateRequest\x1a .nidcpower_grpc.InitiateResponse\x12q\n\x14InitiateWithChannels\x12+.nidcpower_grpc.InitiateWithChannelsRequest\x1a,.nidcpower_grpc.InitiateWithChannelsResponse\x12z\n\x17InvalidateAllAttributes\x12..nidcpower_grpc.InvalidateAllAttributesRequest\x1a/.nidcpower_grpc.InvalidateAllAttributesResponse\x12J\n\x07Measure\x12\x1e.nidcpower_grpc.MeasureRequest\x1a\x1f.nidcpower_grpc.MeasureResponse\x12\x62\n\x0fMeasureMultiple\x12&.nidcpower_grpc.MeasureMultipleRequest\x1a\'.nidcpower_grpc.MeasureMultipleResponse\x12k\n\x12MeasureMultipleLCR\x12).nidcpower_grpc.MeasureMultipleLCRRequest\x1a*.nidcpower_grpc.MeasureMultipleLCRResponse\x12\x83\x01\n\x1aPerformLCRLoadCompensation\x12\x31.nidcpower_grpc.PerformLCRLoadCompensationRequest\x1a\x32.nidcpower_grpc.PerformLCRLoadCompensationResponse\x12\x83\x01\n\x1aPerformLCROpenCompensation\x12\x31.nidcpower_grpc.PerformLCROpenCompensationRequest\x1a\x32.nidcpower_grpc.PerformLCROpenCompensationResponse\x12\xa4\x01\n%PerformLCROpenCustomCableCompensation\x12<.nidcpower_grpc.PerformLCROpenCustomCableCompensationRequest\x1a=.nidcpower_grpc.PerformLCROpenCustomCableCompensationResponse\x12\x86\x01\n\x1bPerformLCRShortCompensation\x12\x32.nidcpower_grpc.PerformLCRShortCompensationRequest\x1a\x33.nidcpower_grpc.PerformLCRShortCompensationResponse\x12\xa7\x01\n&PerformLCRShortCustomCableCompensation\x12=.nidcpower_grpc.PerformLCRShortCustomCableCompensationRequest\x1a>.nidcpower_grpc.PerformLCRShortCustomCableCompensationResponse\x12h\n\x11QueryInCompliance\x12(.nidcpower_grpc.QueryInComplianceRequest\x1a).nidcpower_grpc.QueryInComplianceResponse\x12\x8c\x01\n\x1dQueryLatchedOutputCutoffState\x12\x34.nidcpower_grpc.QueryLatchedOutputCutoffStateRequest\x1a\x35.nidcpower_grpc.QueryLatchedOutputCutoffStateResponse\x12q\n\x14QueryMaxCurrentLimit\x12+.nidcpower_grpc.QueryMaxCurrentLimitRequest\x1a,.nidcpower_grpc.QueryMaxCurrentLimitResponse\x12q\n\x14QueryMaxVoltageLevel\x12+.nidcpower_grpc.QueryMaxVoltageLevelRequest\x1a,.nidcpower_grpc.QueryMaxVoltageLevelResponse\x12q\n\x14QueryMinCurrentLimit\x12+.nidcpower_grpc.QueryMinCurrentLimitRequest\x1a,.nidcpower_grpc.QueryMinCurrentLimitResponse\x12\x65\n\x10QueryOutputState\x12\'.nidcpower_grpc.QueryOutputStateRequest\x1a(.nidcpower_grpc.QueryOutputStateResponse\x12w\n\x16ReadCurrentTemperature\x12-.nidcpower_grpc.ReadCurrentTemperatureRequest\x1a..nidcpower_grpc.ReadCurrentTemperatureResponse\x12\x44\n\x05Reset\x12\x1c.nidcpower_grpc.ResetRequest\x1a\x1d.nidcpower_grpc.ResetResponse\x12V\n\x0bResetDevice\x12\".nidcpower_grpc.ResetDeviceRequest\x1a#.nidcpower_grpc.ResetDeviceResponse\x12t\n\x15ResetInterchangeCheck\x12,.nidcpower_grpc.ResetInterchangeCheckRequest\x1a-.nidcpower_grpc.ResetInterchangeCheckResponse\x12h\n\x11ResetWithChannels\x12(.nidcpower_grpc.ResetWithChannelsRequest\x1a).nidcpower_grpc.ResetWithChannelsResponse\x12h\n\x11ResetWithDefaults\x12(.nidcpower_grpc.ResetWithDefaultsRequest\x1a).nidcpower_grpc.ResetWithDefaultsResponse\x12\\\n\rRevisionQuery\x12$.nidcpower_grpc.RevisionQueryRequest\x1a%.nidcpower_grpc.RevisionQueryResponse\x12M\n\x08SelfTest\x12\x1f.nidcpower_grpc.SelfTestRequest\x1a .nidcpower_grpc.SelfTestResponse\x12z\n\x17SendSoftwareEdgeTrigger\x12..nidcpower_grpc.SendSoftwareEdgeTriggerRequest\x1a/.nidcpower_grpc.SendSoftwareEdgeTriggerResponse\x12\x9e\x01\n#SendSoftwareEdgeTriggerWithChannels\x12:.nidcpower_grpc.SendSoftwareEdgeTriggerWithChannelsRequest\x1a;.nidcpower_grpc.SendSoftwareEdgeTriggerWithChannelsResponse\x12t\n\x15SetAttributeViBoolean\x12,.nidcpower_grpc.SetAttributeViBooleanRequest\x1a-.nidcpower_grpc.SetAttributeViBooleanResponse\x12n\n\x13SetAttributeViInt32\x12*.nidcpower_grpc.SetAttributeViInt32Request\x1a+.nidcpower_grpc.SetAttributeViInt32Response\x12n\n\x13SetAttributeViInt64\x12*.nidcpower_grpc.SetAttributeViInt64Request\x1a+.nidcpower_grpc.SetAttributeViInt64Response\x12q\n\x14SetAttributeViReal64\x12+.nidcpower_grpc.SetAttributeViReal64Request\x1a,.nidcpower_grpc.SetAttributeViReal64Response\x12t\n\x15SetAttributeViSession\x12,.nidcpower_grpc.SetAttributeViSessionRequest\x1a-.nidcpower_grpc.SetAttributeViSessionResponse\x12q\n\x14SetAttributeViString\x12+.nidcpower_grpc.SetAttributeViStringRequest\x1a,.nidcpower_grpc.SetAttributeViStringResponse\x12V\n\x0bSetSequence\x12\".nidcpower_grpc.SetSequenceRequest\x1a#.nidcpower_grpc.SetSequenceResponse\x12Y\n\x0cWaitForEvent\x12#.nidcpower_grpc.WaitForEventRequest\x1a$.nidcpower_grpc.WaitForEventResponse\x12}\n\x18WaitForEventWithChannels\x12/.nidcpower_grpc.WaitForEventWithChannelsRequest\x1a\x30.nidcpower_grpc.WaitForEventWithChannelsResponseBE\n\x13\x63om.ni.grpc.dcpowerB\tNiDCPowerP\x01\xaa\x02 NationalInstruments.Grpc.DCPowerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nidcpower_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.ni.grpc.dcpowerB\tNiDCPowerP\001\252\002 NationalInstruments.Grpc.DCPower'
  _NIDCPOWERINT32ATTRIBUTEVALUES._options = None
  _NIDCPOWERINT32ATTRIBUTEVALUES._serialized_options = b'\020\001'
  _INITIALIZEWITHCHANNELSRESPONSE.fields_by_name['error_message']._options = None
  _INITIALIZEWITHCHANNELSRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _INITIALIZEWITHINDEPENDENTCHANNELSRESPONSE.fields_by_name['error_message']._options = None
  _INITIALIZEWITHINDEPENDENTCHANNELSRESPONSE.fields_by_name['error_message']._serialized_options = b'\030\001'
  _NIDCPOWERATTRIBUTE._serialized_start=28198
  _NIDCPOWERATTRIBUTE._serialized_end=39799
  _APERTURETIMEUNITS._serialized_start=39802
  _APERTURETIMEUNITS._serialized_end=39964
  _AUTOZERO._serialized_start=39966
  _AUTOZERO._serialized_end=40076
  _CURRENTLIMITBEHAVIOR._serialized_start=40079
  _CURRENTLIMITBEHAVIOR._serialized_end=40215
  _DIGITALEDGE._serialized_start=40217
  _DIGITALEDGE._serialized_end=40341
  _EVENT._serialized_start=40344
  _EVENT._serialized_end=40651
  _EXPORTSIGNAL._serialized_start=40654
  _EXPORTSIGNAL._serialized_end=41365
  _LCRCOMPENSATIONTYPE._serialized_start=41368
  _LCRCOMPENSATIONTYPE._serialized_end=41756
  _MEASUREMENTTYPES._serialized_start=41758
  _MEASUREMENTTYPES._serialized_end=41882
  _NIDCPOWERINT32ATTRIBUTEVALUES._serialized_start=41885
  _NIDCPOWERINT32ATTRIBUTEVALUES._serialized_end=47510
  _NIDCPOWERREAL64ATTRIBUTEVALUES._serialized_start=47513
  _NIDCPOWERREAL64ATTRIBUTEVALUES._serialized_end=47695
  _OUTPUTCUTOFFREASON._serialized_start=47698
  _OUTPUTCUTOFFREASON._serialized_end=48477
  _OUTPUTFUNCTION._serialized_start=48480
  _OUTPUTFUNCTION._serialized_end=48723
  _OUTPUTSTATES._serialized_start=48726
  _OUTPUTSTATES._serialized_end=49012
  _POWERLINEFREQUENCIES._serialized_start=49015
  _POWERLINEFREQUENCIES._serialized_end=49179
  _SENDSOFTWAREEDGETRIGGERTYPE._serialized_start=49182
  _SENDSOFTWAREEDGETRIGGERTYPE._serialized_end=49625
  _SENSE._serialized_start=49627
  _SENSE._serialized_end=49722
  _SOURCEMODE._serialized_start=49724
  _SOURCEMODE._serialized_end=49851
  _NILCRLOADCOMPENSATIONSPOT._serialized_start=67
  _NILCRLOADCOMPENSATIONSPOT._serialized_end=197
  _NILCRMEASUREMENT._serialized_start=200
  _NILCRMEASUREMENT._serialized_end=730
  _ABORTREQUEST._serialized_start=732
  _ABORTREQUEST._serialized_end=782
  _ABORTRESPONSE._serialized_start=784
  _ABORTRESPONSE._serialized_end=815
  _ABORTWITHCHANNELSREQUEST._serialized_start=817
  _ABORTWITHCHANNELSREQUEST._serialized_end=901
  _ABORTWITHCHANNELSRESPONSE._serialized_start=903
  _ABORTWITHCHANNELSRESPONSE._serialized_end=946
  _CALSELFCALIBRATEREQUEST._serialized_start=948
  _CALSELFCALIBRATEREQUEST._serialized_end=1031
  _CALSELFCALIBRATERESPONSE._serialized_start=1033
  _CALSELFCALIBRATERESPONSE._serialized_end=1075
  _CLEARERRORREQUEST._serialized_start=1077
  _CLEARERRORREQUEST._serialized_end=1132
  _CLEARERRORRESPONSE._serialized_start=1134
  _CLEARERRORRESPONSE._serialized_end=1170
  _CLEARINTERCHANGEWARNINGSREQUEST._serialized_start=1172
  _CLEARINTERCHANGEWARNINGSREQUEST._serialized_end=1241
  _CLEARINTERCHANGEWARNINGSRESPONSE._serialized_start=1243
  _CLEARINTERCHANGEWARNINGSRESPONSE._serialized_end=1293
  _CLEARLATCHEDOUTPUTCUTOFFSTATEREQUEST._serialized_start=1296
  _CLEARLATCHEDOUTPUTCUTOFFSTATEREQUEST._serialized_end=1525
  _CLEARLATCHEDOUTPUTCUTOFFSTATERESPONSE._serialized_start=1527
  _CLEARLATCHEDOUTPUTCUTOFFSTATERESPONSE._serialized_end=1582
  _CLOSEREQUEST._serialized_start=1584
  _CLOSEREQUEST._serialized_end=1634
  _CLOSERESPONSE._serialized_start=1636
  _CLOSERESPONSE._serialized_end=1667
  _COMMITREQUEST._serialized_start=1669
  _COMMITREQUEST._serialized_end=1720
  _COMMITRESPONSE._serialized_start=1722
  _COMMITRESPONSE._serialized_end=1754
  _COMMITWITHCHANNELSREQUEST._serialized_start=1756
  _COMMITWITHCHANNELSREQUEST._serialized_end=1841
  _COMMITWITHCHANNELSRESPONSE._serialized_start=1843
  _COMMITWITHCHANNELSRESPONSE._serialized_end=1887
  _CONFIGUREAPERTURETIMEREQUEST._serialized_start=1890
  _CONFIGUREAPERTURETIMEREQUEST._serialized_end=2088
  _CONFIGUREAPERTURETIMERESPONSE._serialized_start=2090
  _CONFIGUREAPERTURETIMERESPONSE._serialized_end=2137
  _CONFIGUREAUTOZEROREQUEST._serialized_start=2140
  _CONFIGUREAUTOZEROREQUEST._serialized_end=2314
  _CONFIGUREAUTOZERORESPONSE._serialized_start=2316
  _CONFIGUREAUTOZERORESPONSE._serialized_end=2359
  _CONFIGURECURRENTLEVELREQUEST._serialized_start=2361
  _CONFIGURECURRENTLEVELREQUEST._serialized_end=2464
  _CONFIGURECURRENTLEVELRESPONSE._serialized_start=2466
  _CONFIGURECURRENTLEVELRESPONSE._serialized_end=2513
  _CONFIGURECURRENTLEVELRANGEREQUEST._serialized_start=2515
  _CONFIGURECURRENTLEVELRANGEREQUEST._serialized_end=2623
  _CONFIGURECURRENTLEVELRANGERESPONSE._serialized_start=2625
  _CONFIGURECURRENTLEVELRANGERESPONSE._serialized_end=2677
  _CONFIGURECURRENTLIMITREQUEST._serialized_start=2680
  _CONFIGURECURRENTLIMITREQUEST._serialized_end=2882
  _CONFIGURECURRENTLIMITRESPONSE._serialized_start=2884
  _CONFIGURECURRENTLIMITRESPONSE._serialized_end=2931
  _CONFIGURECURRENTLIMITRANGEREQUEST._serialized_start=2933
  _CONFIGURECURRENTLIMITRANGEREQUEST._serialized_end=3041
  _CONFIGURECURRENTLIMITRANGERESPONSE._serialized_start=3043
  _CONFIGURECURRENTLIMITRANGERESPONSE._serialized_end=3095
  _CONFIGUREDIGITALEDGEMEASURETRIGGERREQUEST._serialized_start=3098
  _CONFIGUREDIGITALEDGEMEASURETRIGGERREQUEST._serialized_end=3279
  _CONFIGUREDIGITALEDGEMEASURETRIGGERRESPONSE._serialized_start=3281
  _CONFIGUREDIGITALEDGEMEASURETRIGGERRESPONSE._serialized_end=3341
  _CONFIGUREDIGITALEDGEMEASURETRIGGERWITHCHANNELSREQUEST._serialized_start=3344
  _CONFIGUREDIGITALEDGEMEASURETRIGGERWITHCHANNELSREQUEST._serialized_end=3559
  _CONFIGUREDIGITALEDGEMEASURETRIGGERWITHCHANNELSRESPONSE._serialized_start=3561
  _CONFIGUREDIGITALEDGEMEASURETRIGGERWITHCHANNELSRESPONSE._serialized_end=3633
  _CONFIGUREDIGITALEDGEPULSETRIGGERREQUEST._serialized_start=3636
  _CONFIGUREDIGITALEDGEPULSETRIGGERREQUEST._serialized_end=3815
  _CONFIGUREDIGITALEDGEPULSETRIGGERRESPONSE._serialized_start=3817
  _CONFIGUREDIGITALEDGEPULSETRIGGERRESPONSE._serialized_end=3875
  _CONFIGUREDIGITALEDGEPULSETRIGGERWITHCHANNELSREQUEST._serialized_start=3878
  _CONFIGUREDIGITALEDGEPULSETRIGGERWITHCHANNELSREQUEST._serialized_end=4091
  _CONFIGUREDIGITALEDGEPULSETRIGGERWITHCHANNELSRESPONSE._serialized_start=4093
  _CONFIGUREDIGITALEDGEPULSETRIGGERWITHCHANNELSRESPONSE._serialized_end=4163
  _CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERREQUEST._serialized_start=4166
  _CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERREQUEST._serialized_end=4355
  _CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERRESPONSE._serialized_start=4357
  _CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERRESPONSE._serialized_end=4425
  _CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERWITHCHANNELSREQUEST._serialized_start=4428
  _CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERWITHCHANNELSREQUEST._serialized_end=4651
  _CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERWITHCHANNELSRESPONSE._serialized_start=4653
  _CONFIGUREDIGITALEDGESEQUENCEADVANCETRIGGERWITHCHANNELSRESPONSE._serialized_end=4733
  _CONFIGUREDIGITALEDGESHUTDOWNTRIGGERWITHCHANNELSREQUEST._serialized_start=4736
  _CONFIGUREDIGITALEDGESHUTDOWNTRIGGERWITHCHANNELSREQUEST._serialized_end=4952
  _CONFIGUREDIGITALEDGESHUTDOWNTRIGGERWITHCHANNELSRESPONSE._serialized_start=4954
  _CONFIGUREDIGITALEDGESHUTDOWNTRIGGERWITHCHANNELSRESPONSE._serialized_end=5027
  _CONFIGUREDIGITALEDGESOURCETRIGGERREQUEST._serialized_start=5030
  _CONFIGUREDIGITALEDGESOURCETRIGGERREQUEST._serialized_end=5210
  _CONFIGUREDIGITALEDGESOURCETRIGGERRESPONSE._serialized_start=5212
  _CONFIGUREDIGITALEDGESOURCETRIGGERRESPONSE._serialized_end=5271
  _CONFIGUREDIGITALEDGESOURCETRIGGERWITHCHANNELSREQUEST._serialized_start=5274
  _CONFIGUREDIGITALEDGESOURCETRIGGERWITHCHANNELSREQUEST._serialized_end=5488
  _CONFIGUREDIGITALEDGESOURCETRIGGERWITHCHANNELSRESPONSE._serialized_start=5490
  _CONFIGUREDIGITALEDGESOURCETRIGGERWITHCHANNELSRESPONSE._serialized_end=5561
  _CONFIGUREDIGITALEDGESTARTTRIGGERREQUEST._serialized_start=5564
  _CONFIGUREDIGITALEDGESTARTTRIGGERREQUEST._serialized_end=5743
  _CONFIGUREDIGITALEDGESTARTTRIGGERRESPONSE._serialized_start=5745
  _CONFIGUREDIGITALEDGESTARTTRIGGERRESPONSE._serialized_end=5803
  _CONFIGUREDIGITALEDGESTARTTRIGGERWITHCHANNELSREQUEST._serialized_start=5806
  _CONFIGUREDIGITALEDGESTARTTRIGGERWITHCHANNELSREQUEST._serialized_end=6019
  _CONFIGUREDIGITALEDGESTARTTRIGGERWITHCHANNELSRESPONSE._serialized_start=6021
  _CONFIGUREDIGITALEDGESTARTTRIGGERWITHCHANNELSRESPONSE._serialized_end=6091
  _CONFIGURELCRCUSTOMCABLECOMPENSATIONREQUEST._serialized_start=6094
  _CONFIGURELCRCUSTOMCABLECOMPENSATIONREQUEST._serialized_end=6236
  _CONFIGURELCRCUSTOMCABLECOMPENSATIONRESPONSE._serialized_start=6238
  _CONFIGURELCRCUSTOMCABLECOMPENSATIONRESPONSE._serialized_end=6299
  _CONFIGUREOUTPUTENABLEDREQUEST._serialized_start=6301
  _CONFIGUREOUTPUTENABLEDREQUEST._serialized_end=6407
  _CONFIGUREOUTPUTENABLEDRESPONSE._serialized_start=6409
  _CONFIGUREOUTPUTENABLEDRESPONSE._serialized_end=6457
  _CONFIGUREOUTPUTFUNCTIONREQUEST._serialized_start=6460
  _CONFIGUREOUTPUTFUNCTIONREQUEST._serialized_end=6643
  _CONFIGUREOUTPUTFUNCTIONRESPONSE._serialized_start=6645
  _CONFIGUREOUTPUTFUNCTIONRESPONSE._serialized_end=6694
  _CONFIGUREOUTPUTRESISTANCEREQUEST._serialized_start=6696
  _CONFIGUREOUTPUTRESISTANCEREQUEST._serialized_end=6808
  _CONFIGUREOUTPUTRESISTANCERESPONSE._serialized_start=6810
  _CONFIGUREOUTPUTRESISTANCERESPONSE._serialized_end=6861
  _CONFIGUREOVPREQUEST._serialized_start=6863
  _CONFIGUREOVPREQUEST._serialized_end=6974
  _CONFIGUREOVPRESPONSE._serialized_start=6976
  _CONFIGUREOVPRESPONSE._serialized_end=7014
  _CONFIGUREPOWERLINEFREQUENCYREQUEST._serialized_start=7017
  _CONFIGUREPOWERLINEFREQUENCYREQUEST._serialized_end=7221
  _CONFIGUREPOWERLINEFREQUENCYRESPONSE._serialized_start=7223
  _CONFIGUREPOWERLINEFREQUENCYRESPONSE._serialized_end=7276
  _CONFIGUREPULSEBIASCURRENTLEVELREQUEST._serialized_start=7278
  _CONFIGUREPULSEBIASCURRENTLEVELREQUEST._serialized_end=7390
  _CONFIGUREPULSEBIASCURRENTLEVELRESPONSE._serialized_start=7392
  _CONFIGUREPULSEBIASCURRENTLEVELRESPONSE._serialized_end=7448
  _CONFIGUREPULSEBIASCURRENTLIMITREQUEST._serialized_start=7450
  _CONFIGUREPULSEBIASCURRENTLIMITREQUEST._serialized_end=7562
  _CONFIGUREPULSEBIASCURRENTLIMITRESPONSE._serialized_start=7564
  _CONFIGUREPULSEBIASCURRENTLIMITRESPONSE._serialized_end=7620
  _CONFIGUREPULSEBIASVOLTAGELEVELREQUEST._serialized_start=7622
  _CONFIGUREPULSEBIASVOLTAGELEVELREQUEST._serialized_end=7734
  _CONFIGUREPULSEBIASVOLTAGELEVELRESPONSE._serialized_start=7736
  _CONFIGUREPULSEBIASVOLTAGELEVELRESPONSE._serialized_end=7792
  _CONFIGUREPULSEBIASVOLTAGELIMITREQUEST._serialized_start=7794
  _CONFIGUREPULSEBIASVOLTAGELIMITREQUEST._serialized_end=7906
  _CONFIGUREPULSEBIASVOLTAGELIMITRESPONSE._serialized_start=7908
  _CONFIGUREPULSEBIASVOLTAGELIMITRESPONSE._serialized_end=7964
  _CONFIGUREPULSECURRENTLEVELREQUEST._serialized_start=7966
  _CONFIGUREPULSECURRENTLEVELREQUEST._serialized_end=8074
  _CONFIGUREPULSECURRENTLEVELRESPONSE._serialized_start=8076
  _CONFIGUREPULSECURRENTLEVELRESPONSE._serialized_end=8128
  _CONFIGUREPULSECURRENTLEVELRANGEREQUEST._serialized_start=8130
  _CONFIGUREPULSECURRENTLEVELRANGEREQUEST._serialized_end=8243
  _CONFIGUREPULSECURRENTLEVELRANGERESPONSE._serialized_start=8245
  _CONFIGUREPULSECURRENTLEVELRANGERESPONSE._serialized_end=8302
  _CONFIGUREPULSECURRENTLIMITREQUEST._serialized_start=8304
  _CONFIGUREPULSECURRENTLIMITREQUEST._serialized_end=8412
  _CONFIGUREPULSECURRENTLIMITRESPONSE._serialized_start=8414
  _CONFIGUREPULSECURRENTLIMITRESPONSE._serialized_end=8466
  _CONFIGUREPULSECURRENTLIMITRANGEREQUEST._serialized_start=8468
  _CONFIGUREPULSECURRENTLIMITRANGEREQUEST._serialized_end=8581
  _CONFIGUREPULSECURRENTLIMITRANGERESPONSE._serialized_start=8583
  _CONFIGUREPULSECURRENTLIMITRANGERESPONSE._serialized_end=8640
  _CONFIGUREPULSEVOLTAGELEVELREQUEST._serialized_start=8642
  _CONFIGUREPULSEVOLTAGELEVELREQUEST._serialized_end=8750
  _CONFIGUREPULSEVOLTAGELEVELRESPONSE._serialized_start=8752
  _CONFIGUREPULSEVOLTAGELEVELRESPONSE._serialized_end=8804
  _CONFIGUREPULSEVOLTAGELEVELRANGEREQUEST._serialized_start=8806
  _CONFIGUREPULSEVOLTAGELEVELRANGEREQUEST._serialized_end=8919
  _CONFIGUREPULSEVOLTAGELEVELRANGERESPONSE._serialized_start=8921
  _CONFIGUREPULSEVOLTAGELEVELRANGERESPONSE._serialized_end=8978
  _CONFIGUREPULSEVOLTAGELIMITREQUEST._serialized_start=8980
  _CONFIGUREPULSEVOLTAGELIMITREQUEST._serialized_end=9088
  _CONFIGUREPULSEVOLTAGELIMITRESPONSE._serialized_start=9090
  _CONFIGUREPULSEVOLTAGELIMITRESPONSE._serialized_end=9142
  _CONFIGUREPULSEVOLTAGELIMITRANGEREQUEST._serialized_start=9144
  _CONFIGUREPULSEVOLTAGELIMITRANGEREQUEST._serialized_end=9257
  _CONFIGUREPULSEVOLTAGELIMITRANGERESPONSE._serialized_start=9259
  _CONFIGUREPULSEVOLTAGELIMITRANGERESPONSE._serialized_end=9316
  _CONFIGURESENSEREQUEST._serialized_start=9319
  _CONFIGURESENSEREQUEST._serialized_end=9475
  _CONFIGURESENSERESPONSE._serialized_start=9477
  _CONFIGURESENSERESPONSE._serialized_end=9517
  _CONFIGURESOFTWAREEDGEMEASURETRIGGERREQUEST._serialized_start=9519
  _CONFIGURESOFTWAREEDGEMEASURETRIGGERREQUEST._serialized_end=9599
  _CONFIGURESOFTWAREEDGEMEASURETRIGGERRESPONSE._serialized_start=9601
  _CONFIGURESOFTWAREEDGEMEASURETRIGGERRESPONSE._serialized_end=9662
  _CONFIGURESOFTWAREEDGEMEASURETRIGGERWITHCHANNELSREQUEST._serialized_start=9664
  _CONFIGURESOFTWAREEDGEMEASURETRIGGERWITHCHANNELSREQUEST._serialized_end=9778
  _CONFIGURESOFTWAREEDGEMEASURETRIGGERWITHCHANNELSRESPONSE._serialized_start=9780
  _CONFIGURESOFTWAREEDGEMEASURETRIGGERWITHCHANNELSRESPONSE._serialized_end=9853
  _CONFIGURESOFTWAREEDGEPULSETRIGGERREQUEST._serialized_start=9855
  _CONFIGURESOFTWAREEDGEPULSETRIGGERREQUEST._serialized_end=9933
  _CONFIGURESOFTWAREEDGEPULSETRIGGERRESPONSE._serialized_start=9935
  _CONFIGURESOFTWAREEDGEPULSETRIGGERRESPONSE._serialized_end=9994
  _CONFIGURESOFTWAREEDGEPULSETRIGGERWITHCHANNELSREQUEST._serialized_start=9996
  _CONFIGURESOFTWAREEDGEPULSETRIGGERWITHCHANNELSREQUEST._serialized_end=10108
  _CONFIGURESOFTWAREEDGEPULSETRIGGERWITHCHANNELSRESPONSE._serialized_start=10110
  _CONFIGURESOFTWAREEDGEPULSETRIGGERWITHCHANNELSRESPONSE._serialized_end=10181
  _CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERREQUEST._serialized_start=10183
  _CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERREQUEST._serialized_end=10271
  _CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERRESPONSE._serialized_start=10273
  _CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERRESPONSE._serialized_end=10342
  _CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERWITHCHANNELSREQUEST._serialized_start=10344
  _CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERWITHCHANNELSREQUEST._serialized_end=10466
  _CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERWITHCHANNELSRESPONSE._serialized_start=10468
  _CONFIGURESOFTWAREEDGESEQUENCEADVANCETRIGGERWITHCHANNELSRESPONSE._serialized_end=10549
  _CONFIGURESOFTWAREEDGESHUTDOWNTRIGGERWITHCHANNELSREQUEST._serialized_start=10551
  _CONFIGURESOFTWAREEDGESHUTDOWNTRIGGERWITHCHANNELSREQUEST._serialized_end=10666
  _CONFIGURESOFTWAREEDGESHUTDOWNTRIGGERWITHCHANNELSRESPONSE._serialized_start=10668
  _CONFIGURESOFTWAREEDGESHUTDOWNTRIGGERWITHCHANNELSRESPONSE._serialized_end=10742
  _CONFIGURESOFTWAREEDGESOURCETRIGGERREQUEST._serialized_start=10744
  _CONFIGURESOFTWAREEDGESOURCETRIGGERREQUEST._serialized_end=10823
  _CONFIGURESOFTWAREEDGESOURCETRIGGERRESPONSE._serialized_start=10825
  _CONFIGURESOFTWAREEDGESOURCETRIGGERRESPONSE._serialized_end=10885
  _CONFIGURESOFTWAREEDGESOURCETRIGGERWITHCHANNELSREQUEST._serialized_start=10887
  _CONFIGURESOFTWAREEDGESOURCETRIGGERWITHCHANNELSREQUEST._serialized_end=11000
  _CONFIGURESOFTWAREEDGESOURCETRIGGERWITHCHANNELSRESPONSE._serialized_start=11002
  _CONFIGURESOFTWAREEDGESOURCETRIGGERWITHCHANNELSRESPONSE._serialized_end=11074
  _CONFIGURESOFTWAREEDGESTARTTRIGGERREQUEST._serialized_start=11076
  _CONFIGURESOFTWAREEDGESTARTTRIGGERREQUEST._serialized_end=11154
  _CONFIGURESOFTWAREEDGESTARTTRIGGERRESPONSE._serialized_start=11156
  _CONFIGURESOFTWAREEDGESTARTTRIGGERRESPONSE._serialized_end=11215
  _CONFIGURESOFTWAREEDGESTARTTRIGGERWITHCHANNELSREQUEST._serialized_start=11217
  _CONFIGURESOFTWAREEDGESTARTTRIGGERWITHCHANNELSREQUEST._serialized_end=11329
  _CONFIGURESOFTWAREEDGESTARTTRIGGERWITHCHANNELSRESPONSE._serialized_start=11331
  _CONFIGURESOFTWAREEDGESTARTTRIGGERWITHCHANNELSRESPONSE._serialized_end=11402
  _CONFIGURESOURCEMODEREQUEST._serialized_start=11405
  _CONFIGURESOURCEMODEREQUEST._serialized_end=11567
  _CONFIGURESOURCEMODERESPONSE._serialized_start=11569
  _CONFIGURESOURCEMODERESPONSE._serialized_end=11614
  _CONFIGURESOURCEMODEWITHCHANNELSREQUEST._serialized_start=11617
  _CONFIGURESOURCEMODEWITHCHANNELSREQUEST._serialized_end=11813
  _CONFIGURESOURCEMODEWITHCHANNELSRESPONSE._serialized_start=11815
  _CONFIGURESOURCEMODEWITHCHANNELSRESPONSE._serialized_end=11872
  _CONFIGUREVOLTAGELEVELREQUEST._serialized_start=11874
  _CONFIGUREVOLTAGELEVELREQUEST._serialized_end=11977
  _CONFIGUREVOLTAGELEVELRESPONSE._serialized_start=11979
  _CONFIGUREVOLTAGELEVELRESPONSE._serialized_end=12026
  _CONFIGUREVOLTAGELEVELRANGEREQUEST._serialized_start=12028
  _CONFIGUREVOLTAGELEVELRANGEREQUEST._serialized_end=12136
  _CONFIGUREVOLTAGELEVELRANGERESPONSE._serialized_start=12138
  _CONFIGUREVOLTAGELEVELRANGERESPONSE._serialized_end=12190
  _CONFIGUREVOLTAGELIMITREQUEST._serialized_start=12192
  _CONFIGUREVOLTAGELIMITREQUEST._serialized_end=12295
  _CONFIGUREVOLTAGELIMITRESPONSE._serialized_start=12297
  _CONFIGUREVOLTAGELIMITRESPONSE._serialized_end=12344
  _CONFIGUREVOLTAGELIMITRANGEREQUEST._serialized_start=12346
  _CONFIGUREVOLTAGELIMITRANGEREQUEST._serialized_end=12454
  _CONFIGUREVOLTAGELIMITRANGERESPONSE._serialized_start=12456
  _CONFIGUREVOLTAGELIMITRANGERESPONSE._serialized_end=12508
  _CREATEADVANCEDSEQUENCEREQUEST._serialized_start=12511
  _CREATEADVANCEDSEQUENCEREQUEST._serialized_end=12656
  _CREATEADVANCEDSEQUENCERESPONSE._serialized_start=12658
  _CREATEADVANCEDSEQUENCERESPONSE._serialized_end=12706
  _CREATEADVANCEDSEQUENCECOMMITSTEPWITHCHANNELSREQUEST._serialized_start=12709
  _CREATEADVANCEDSEQUENCECOMMITSTEPWITHCHANNELSREQUEST._serialized_end=12848
  _CREATEADVANCEDSEQUENCECOMMITSTEPWITHCHANNELSRESPONSE._serialized_start=12850
  _CREATEADVANCEDSEQUENCECOMMITSTEPWITHCHANNELSRESPONSE._serialized_end=12920
  _CREATEADVANCEDSEQUENCESTEPREQUEST._serialized_start=12922
  _CREATEADVANCEDSEQUENCESTEPREQUEST._serialized_end=13021
  _CREATEADVANCEDSEQUENCESTEPRESPONSE._serialized_start=13023
  _CREATEADVANCEDSEQUENCESTEPRESPONSE._serialized_end=13075
  _CREATEADVANCEDSEQUENCESTEPWITHCHANNELSREQUEST._serialized_start=13078
  _CREATEADVANCEDSEQUENCESTEPWITHCHANNELSREQUEST._serialized_end=13211
  _CREATEADVANCEDSEQUENCESTEPWITHCHANNELSRESPONSE._serialized_start=13213
  _CREATEADVANCEDSEQUENCESTEPWITHCHANNELSRESPONSE._serialized_end=13277
  _CREATEADVANCEDSEQUENCEWITHCHANNELSREQUEST._serialized_start=13280
  _CREATEADVANCEDSEQUENCEWITHCHANNELSREQUEST._serialized_end=13459
  _CREATEADVANCEDSEQUENCEWITHCHANNELSRESPONSE._serialized_start=13461
  _CREATEADVANCEDSEQUENCEWITHCHANNELSRESPONSE._serialized_end=13521
  _DELETEADVANCEDSEQUENCEREQUEST._serialized_start=13523
  _DELETEADVANCEDSEQUENCEREQUEST._serialized_end=13613
  _DELETEADVANCEDSEQUENCERESPONSE._serialized_start=13615
  _DELETEADVANCEDSEQUENCERESPONSE._serialized_end=13663
  _DELETEADVANCEDSEQUENCEWITHCHANNELSREQUEST._serialized_start=13665
  _DELETEADVANCEDSEQUENCEWITHCHANNELSREQUEST._serialized_end=13789
  _DELETEADVANCEDSEQUENCEWITHCHANNELSRESPONSE._serialized_start=13791
  _DELETEADVANCEDSEQUENCEWITHCHANNELSRESPONSE._serialized_end=13851
  _DISABLEREQUEST._serialized_start=13853
  _DISABLEREQUEST._serialized_end=13905
  _DISABLERESPONSE._serialized_start=13907
  _DISABLERESPONSE._serialized_end=13940
  _DISABLEPULSETRIGGERREQUEST._serialized_start=13942
  _DISABLEPULSETRIGGERREQUEST._serialized_end=14006
  _DISABLEPULSETRIGGERRESPONSE._serialized_start=14008
  _DISABLEPULSETRIGGERRESPONSE._serialized_end=14053
  _DISABLEPULSETRIGGERWITHCHANNELSREQUEST._serialized_start=14055
  _DISABLEPULSETRIGGERWITHCHANNELSREQUEST._serialized_end=14153
  _DISABLEPULSETRIGGERWITHCHANNELSRESPONSE._serialized_start=14155
  _DISABLEPULSETRIGGERWITHCHANNELSRESPONSE._serialized_end=14212
  _DISABLESEQUENCEADVANCETRIGGERREQUEST._serialized_start=14214
  _DISABLESEQUENCEADVANCETRIGGERREQUEST._serialized_end=14288
  _DISABLESEQUENCEADVANCETRIGGERRESPONSE._serialized_start=14290
  _DISABLESEQUENCEADVANCETRIGGERRESPONSE._serialized_end=14345
  _DISABLESEQUENCEADVANCETRIGGERWITHCHANNELSREQUEST._serialized_start=14347
  _DISABLESEQUENCEADVANCETRIGGERWITHCHANNELSREQUEST._serialized_end=14455
  _DISABLESEQUENCEADVANCETRIGGERWITHCHANNELSRESPONSE._serialized_start=14457
  _DISABLESEQUENCEADVANCETRIGGERWITHCHANNELSRESPONSE._serialized_end=14524
  _DISABLESHUTDOWNTRIGGERWITHCHANNELSREQUEST._serialized_start=14526
  _DISABLESHUTDOWNTRIGGERWITHCHANNELSREQUEST._serialized_end=14627
  _DISABLESHUTDOWNTRIGGERWITHCHANNELSRESPONSE._serialized_start=14629
  _DISABLESHUTDOWNTRIGGERWITHCHANNELSRESPONSE._serialized_end=14689
  _DISABLESOURCETRIGGERREQUEST._serialized_start=14691
  _DISABLESOURCETRIGGERREQUEST._serialized_end=14756
  _DISABLESOURCETRIGGERRESPONSE._serialized_start=14758
  _DISABLESOURCETRIGGERRESPONSE._serialized_end=14804
  _DISABLESOURCETRIGGERWITHCHANNELSREQUEST._serialized_start=14806
  _DISABLESOURCETRIGGERWITHCHANNELSREQUEST._serialized_end=14905
  _DISABLESOURCETRIGGERWITHCHANNELSRESPONSE._serialized_start=14907
  _DISABLESOURCETRIGGERWITHCHANNELSRESPONSE._serialized_end=14965
  _DISABLESTARTTRIGGERREQUEST._serialized_start=14967
  _DISABLESTARTTRIGGERREQUEST._serialized_end=15031
  _DISABLESTARTTRIGGERRESPONSE._serialized_start=15033
  _DISABLESTARTTRIGGERRESPONSE._serialized_end=15078
  _DISABLESTARTTRIGGERWITHCHANNELSREQUEST._serialized_start=15080
  _DISABLESTARTTRIGGERWITHCHANNELSREQUEST._serialized_end=15178
  _DISABLESTARTTRIGGERWITHCHANNELSRESPONSE._serialized_start=15180
  _DISABLESTARTTRIGGERWITHCHANNELSRESPONSE._serialized_end=15237
  _ERRORMESSAGEREQUEST._serialized_start=15239
  _ERRORMESSAGEREQUEST._serialized_end=15316
  _ERRORMESSAGERESPONSE._serialized_start=15318
  _ERRORMESSAGERESPONSE._serialized_end=15379
  _ERRORQUERYREQUEST._serialized_start=15381
  _ERRORQUERYREQUEST._serialized_end=15436
  _ERRORQUERYRESPONSE._serialized_start=15438
  _ERRORQUERYRESPONSE._serialized_end=15517
  _EXPORTATTRIBUTECONFIGURATIONBUFFERREQUEST._serialized_start=15519
  _EXPORTATTRIBUTECONFIGURATIONBUFFERREQUEST._serialized_end=15598
  _EXPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE._serialized_start=15600
  _EXPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE._serialized_end=15683
  _EXPORTATTRIBUTECONFIGURATIONFILEREQUEST._serialized_start=15685
  _EXPORTATTRIBUTECONFIGURATIONFILEREQUEST._serialized_end=15781
  _EXPORTATTRIBUTECONFIGURATIONFILERESPONSE._serialized_start=15783
  _EXPORTATTRIBUTECONFIGURATIONFILERESPONSE._serialized_end=15841
  _EXPORTSIGNALREQUEST._serialized_start=15844
  _EXPORTSIGNALREQUEST._serialized_end=16038
  _EXPORTSIGNALRESPONSE._serialized_start=16040
  _EXPORTSIGNALRESPONSE._serialized_end=16078
  _EXPORTSIGNALWITHCHANNELSREQUEST._serialized_start=16081
  _EXPORTSIGNALWITHCHANNELSREQUEST._serialized_end=16309
  _EXPORTSIGNALWITHCHANNELSRESPONSE._serialized_start=16311
  _EXPORTSIGNALWITHCHANNELSRESPONSE._serialized_end=16361
  _FETCHMULTIPLEREQUEST._serialized_start=16363
  _FETCHMULTIPLEREQUEST._serialized_end=16475
  _FETCHMULTIPLERESPONSE._serialized_start=16478
  _FETCHMULTIPLERESPONSE._serialized_end=16622
  _FETCHMULTIPLELCRREQUEST._serialized_start=16624
  _FETCHMULTIPLELCRREQUEST._serialized_end=16739
  _FETCHMULTIPLELCRRESPONSE._serialized_start=16741
  _FETCHMULTIPLELCRRESPONSE._serialized_end=16861
  _GETATTRIBUTEVIBOOLEANREQUEST._serialized_start=16864
  _GETATTRIBUTEVIBOOLEANREQUEST._serialized_end=17010
  _GETATTRIBUTEVIBOOLEANRESPONSE._serialized_start=17012
  _GETATTRIBUTEVIBOOLEANRESPONSE._serialized_end=17084
  _GETATTRIBUTEVIINT32REQUEST._serialized_start=17087
  _GETATTRIBUTEVIINT32REQUEST._serialized_end=17231
  _GETATTRIBUTEVIINT32RESPONSE._serialized_start=17233
  _GETATTRIBUTEVIINT32RESPONSE._serialized_end=17303
  _GETATTRIBUTEVIINT64REQUEST._serialized_start=17306
  _GETATTRIBUTEVIINT64REQUEST._serialized_end=17450
  _GETATTRIBUTEVIINT64RESPONSE._serialized_start=17452
  _GETATTRIBUTEVIINT64RESPONSE._serialized_end=17522
  _GETATTRIBUTEVIREAL64REQUEST._serialized_start=17525
  _GETATTRIBUTEVIREAL64REQUEST._serialized_end=17670
  _GETATTRIBUTEVIREAL64RESPONSE._serialized_start=17672
  _GETATTRIBUTEVIREAL64RESPONSE._serialized_end=17743
  _GETATTRIBUTEVISESSIONREQUEST._serialized_start=17746
  _GETATTRIBUTEVISESSIONREQUEST._serialized_end=17892
  _GETATTRIBUTEVISESSIONRESPONSE._serialized_start=17894
  _GETATTRIBUTEVISESSIONRESPONSE._serialized_end=17990
  _GETATTRIBUTEVISTRINGREQUEST._serialized_start=17993
  _GETATTRIBUTEVISTRINGREQUEST._serialized_end=18138
  _GETATTRIBUTEVISTRINGRESPONSE._serialized_start=18140
  _GETATTRIBUTEVISTRINGRESPONSE._serialized_end=18211
  _GETCHANNELNAMEREQUEST._serialized_start=18213
  _GETCHANNELNAMEREQUEST._serialized_end=18287
  _GETCHANNELNAMERESPONSE._serialized_start=18289
  _GETCHANNELNAMERESPONSE._serialized_end=18351
  _GETCHANNELNAMEFROMSTRINGREQUEST._serialized_start=18353
  _GETCHANNELNAMEFROMSTRINGREQUEST._serialized_end=18437
  _GETCHANNELNAMEFROMSTRINGRESPONSE._serialized_start=18439
  _GETCHANNELNAMEFROMSTRINGRESPONSE._serialized_end=18511
  _GETERRORREQUEST._serialized_start=18513
  _GETERRORREQUEST._serialized_end=18566
  _GETERRORRESPONSE._serialized_start=18568
  _GETERRORRESPONSE._serialized_end=18637
  _GETEXTCALLASTDATEANDTIMEREQUEST._serialized_start=18639
  _GETEXTCALLASTDATEANDTIMEREQUEST._serialized_end=18708
  _GETEXTCALLASTDATEANDTIMERESPONSE._serialized_start=18710
  _GETEXTCALLASTDATEANDTIMERESPONSE._serialized_end=18832
  _GETEXTCALLASTTEMPREQUEST._serialized_start=18834
  _GETEXTCALLASTTEMPREQUEST._serialized_end=18896
  _GETEXTCALLASTTEMPRESPONSE._serialized_start=18898
  _GETEXTCALLASTTEMPRESPONSE._serialized_end=18962
  _GETEXTCALRECOMMENDEDINTERVALREQUEST._serialized_start=18964
  _GETEXTCALRECOMMENDEDINTERVALREQUEST._serialized_end=19037
  _GETEXTCALRECOMMENDEDINTERVALRESPONSE._serialized_start=19039
  _GETEXTCALRECOMMENDEDINTERVALRESPONSE._serialized_end=19109
  _GETLCRCOMPENSATIONLASTDATEANDTIMEREQUEST._serialized_start=19112
  _GETLCRCOMPENSATIONLASTDATEANDTIMEREQUEST._serialized_end=19337
  _GETLCRCOMPENSATIONLASTDATEANDTIMERESPONSE._serialized_start=19340
  _GETLCRCOMPENSATIONLASTDATEANDTIMERESPONSE._serialized_end=19471
  _GETLCRCUSTOMCABLECOMPENSATIONDATAREQUEST._serialized_start=19473
  _GETLCRCUSTOMCABLECOMPENSATIONDATAREQUEST._serialized_end=19573
  _GETLCRCUSTOMCABLECOMPENSATIONDATARESPONSE._serialized_start=19575
  _GETLCRCUSTOMCABLECOMPENSATIONDATARESPONSE._serialized_end=19674
  _GETNEXTCOERCIONRECORDREQUEST._serialized_start=19676
  _GETNEXTCOERCIONRECORDREQUEST._serialized_end=19742
  _GETNEXTCOERCIONRECORDRESPONSE._serialized_start=19744
  _GETNEXTCOERCIONRECORDRESPONSE._serialized_end=19816
  _GETNEXTINTERCHANGEWARNINGREQUEST._serialized_start=19818
  _GETNEXTINTERCHANGEWARNINGREQUEST._serialized_end=19888
  _GETNEXTINTERCHANGEWARNINGRESPONSE._serialized_start=19890
  _GETNEXTINTERCHANGEWARNINGRESPONSE._serialized_end=19970
  _GETSELFCALLASTDATEANDTIMEREQUEST._serialized_start=19972
  _GETSELFCALLASTDATEANDTIMEREQUEST._serialized_end=20042
  _GETSELFCALLASTDATEANDTIMERESPONSE._serialized_start=20044
  _GETSELFCALLASTDATEANDTIMERESPONSE._serialized_end=20167
  _GETSELFCALLASTTEMPREQUEST._serialized_start=20169
  _GETSELFCALLASTTEMPREQUEST._serialized_end=20232
  _GETSELFCALLASTTEMPRESPONSE._serialized_start=20234
  _GETSELFCALLASTTEMPRESPONSE._serialized_end=20299
  _IMPORTATTRIBUTECONFIGURATIONBUFFERREQUEST._serialized_start=20301
  _IMPORTATTRIBUTECONFIGURATIONBUFFERREQUEST._serialized_end=20403
  _IMPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE._serialized_start=20405
  _IMPORTATTRIBUTECONFIGURATIONBUFFERRESPONSE._serialized_end=20465
  _IMPORTATTRIBUTECONFIGURATIONFILEREQUEST._serialized_start=20467
  _IMPORTATTRIBUTECONFIGURATIONFILEREQUEST._serialized_end=20563
  _IMPORTATTRIBUTECONFIGURATIONFILERESPONSE._serialized_start=20565
  _IMPORTATTRIBUTECONFIGURATIONFILERESPONSE._serialized_end=20623
  _INITIALIZEWITHCHANNELSREQUEST._serialized_start=20626
  _INITIALIZEWITHCHANNELSREQUEST._serialized_end=20837
  _INITIALIZEWITHCHANNELSRESPONSE._serialized_start=20840
  _INITIALIZEWITHCHANNELSRESPONSE._serialized_end=20984
  _INITIALIZEWITHINDEPENDENTCHANNELSREQUEST._serialized_start=20987
  _INITIALIZEWITHINDEPENDENTCHANNELSREQUEST._serialized_end=21191
  _INITIALIZEWITHINDEPENDENTCHANNELSRESPONSE._serialized_start=21194
  _INITIALIZEWITHINDEPENDENTCHANNELSRESPONSE._serialized_end=21349
  _INITIATEREQUEST._serialized_start=21351
  _INITIATEREQUEST._serialized_end=21404
  _INITIATERESPONSE._serialized_start=21406
  _INITIATERESPONSE._serialized_end=21440
  _INITIATEWITHCHANNELSREQUEST._serialized_start=21442
  _INITIATEWITHCHANNELSREQUEST._serialized_end=21529
  _INITIATEWITHCHANNELSRESPONSE._serialized_start=21531
  _INITIATEWITHCHANNELSRESPONSE._serialized_end=21577
  _INVALIDATEALLATTRIBUTESREQUEST._serialized_start=21579
  _INVALIDATEALLATTRIBUTESREQUEST._serialized_end=21647
  _INVALIDATEALLATTRIBUTESRESPONSE._serialized_start=21649
  _INVALIDATEALLATTRIBUTESRESPONSE._serialized_end=21698
  _MEASUREREQUEST._serialized_start=21701
  _MEASUREREQUEST._serialized_end=21894
  _MEASURERESPONSE._serialized_start=21896
  _MEASURERESPONSE._serialized_end=21950
  _MEASUREMULTIPLEREQUEST._serialized_start=21952
  _MEASUREMULTIPLEREQUEST._serialized_end=22034
  _MEASUREMULTIPLERESPONSE._serialized_start=22036
  _MEASUREMULTIPLERESPONSE._serialized_end=22137
  _MEASUREMULTIPLELCRREQUEST._serialized_start=22139
  _MEASUREMULTIPLELCRREQUEST._serialized_end=22224
  _MEASUREMULTIPLELCRRESPONSE._serialized_start=22226
  _MEASUREMULTIPLELCRRESPONSE._serialized_end=22326
  _PERFORMLCRLOADCOMPENSATIONREQUEST._serialized_start=22329
  _PERFORMLCRLOADCOMPENSATIONREQUEST._serialized_end=22493
  _PERFORMLCRLOADCOMPENSATIONRESPONSE._serialized_start=22495
  _PERFORMLCRLOADCOMPENSATIONRESPONSE._serialized_end=22547
  _PERFORMLCROPENCOMPENSATIONREQUEST._serialized_start=22549
  _PERFORMLCROPENCOMPENSATIONREQUEST._serialized_end=22674
  _PERFORMLCROPENCOMPENSATIONRESPONSE._serialized_start=22676
  _PERFORMLCROPENCOMPENSATIONRESPONSE._serialized_end=22728
  _PERFORMLCROPENCUSTOMCABLECOMPENSATIONREQUEST._serialized_start=22730
  _PERFORMLCROPENCUSTOMCABLECOMPENSATIONREQUEST._serialized_end=22834
  _PERFORMLCROPENCUSTOMCABLECOMPENSATIONRESPONSE._serialized_start=22836
  _PERFORMLCROPENCUSTOMCABLECOMPENSATIONRESPONSE._serialized_end=22899
  _PERFORMLCRSHORTCOMPENSATIONREQUEST._serialized_start=22901
  _PERFORMLCRSHORTCOMPENSATIONREQUEST._serialized_end=23027
  _PERFORMLCRSHORTCOMPENSATIONRESPONSE._serialized_start=23029
  _PERFORMLCRSHORTCOMPENSATIONRESPONSE._serialized_end=23082
  _PERFORMLCRSHORTCUSTOMCABLECOMPENSATIONREQUEST._serialized_start=23084
  _PERFORMLCRSHORTCUSTOMCABLECOMPENSATIONREQUEST._serialized_end=23189
  _PERFORMLCRSHORTCUSTOMCABLECOMPENSATIONRESPONSE._serialized_start=23191
  _PERFORMLCRSHORTCUSTOMCABLECOMPENSATIONRESPONSE._serialized_end=23255
  _QUERYINCOMPLIANCEREQUEST._serialized_start=23257
  _QUERYINCOMPLIANCEREQUEST._serialized_end=23341
  _QUERYINCOMPLIANCERESPONSE._serialized_start=23343
  _QUERYINCOMPLIANCERESPONSE._serialized_end=23409
  _QUERYLATCHEDOUTPUTCUTOFFSTATEREQUEST._serialized_start=23412
  _QUERYLATCHEDOUTPUTCUTOFFSTATEREQUEST._serialized_end=23641
  _QUERYLATCHEDOUTPUTCUTOFFSTATERESPONSE._serialized_start=23643
  _QUERYLATCHEDOUTPUTCUTOFFSTATERESPONSE._serialized_end=23727
  _QUERYMAXCURRENTLIMITREQUEST._serialized_start=23729
  _QUERYMAXCURRENTLIMITREQUEST._serialized_end=23839
  _QUERYMAXCURRENTLIMITRESPONSE._serialized_start=23841
  _QUERYMAXCURRENTLIMITRESPONSE._serialized_end=23914
  _QUERYMAXVOLTAGELEVELREQUEST._serialized_start=23916
  _QUERYMAXVOLTAGELEVELREQUEST._serialized_end=24026
  _QUERYMAXVOLTAGELEVELRESPONSE._serialized_start=24028
  _QUERYMAXVOLTAGELEVELRESPONSE._serialized_end=24101
  _QUERYMINCURRENTLIMITREQUEST._serialized_start=24103
  _QUERYMINCURRENTLIMITREQUEST._serialized_end=24213
  _QUERYMINCURRENTLIMITRESPONSE._serialized_start=24215
  _QUERYMINCURRENTLIMITRESPONSE._serialized_end=24288
  _QUERYOUTPUTSTATEREQUEST._serialized_start=24291
  _QUERYOUTPUTSTATEREQUEST._serialized_end=24477
  _QUERYOUTPUTSTATERESPONSE._serialized_start=24479
  _QUERYOUTPUTSTATERESPONSE._serialized_end=24539
  _READCURRENTTEMPERATUREREQUEST._serialized_start=24541
  _READCURRENTTEMPERATUREREQUEST._serialized_end=24608
  _READCURRENTTEMPERATURERESPONSE._serialized_start=24610
  _READCURRENTTEMPERATURERESPONSE._serialized_end=24679
  _RESETREQUEST._serialized_start=24681
  _RESETREQUEST._serialized_end=24731
  _RESETRESPONSE._serialized_start=24733
  _RESETRESPONSE._serialized_end=24764
  _RESETDEVICEREQUEST._serialized_start=24766
  _RESETDEVICEREQUEST._serialized_end=24822
  _RESETDEVICERESPONSE._serialized_start=24824
  _RESETDEVICERESPONSE._serialized_end=24861
  _RESETINTERCHANGECHECKREQUEST._serialized_start=24863
  _RESETINTERCHANGECHECKREQUEST._serialized_end=24929
  _RESETINTERCHANGECHECKRESPONSE._serialized_start=24931
  _RESETINTERCHANGECHECKRESPONSE._serialized_end=24978
  _RESETWITHCHANNELSREQUEST._serialized_start=24980
  _RESETWITHCHANNELSREQUEST._serialized_end=25064
  _RESETWITHCHANNELSRESPONSE._serialized_start=25066
  _RESETWITHCHANNELSRESPONSE._serialized_end=25109
  _RESETWITHDEFAULTSREQUEST._serialized_start=25111
  _RESETWITHDEFAULTSREQUEST._serialized_end=25173
  _RESETWITHDEFAULTSRESPONSE._serialized_start=25175
  _RESETWITHDEFAULTSRESPONSE._serialized_end=25218
  _REVISIONQUERYREQUEST._serialized_start=25220
  _REVISIONQUERYREQUEST._serialized_end=25278
  _REVISIONQUERYRESPONSE._serialized_start=25280
  _REVISIONQUERYRESPONSE._serialized_end=25382
  _SELFTESTREQUEST._serialized_start=25384
  _SELFTESTREQUEST._serialized_end=25437
  _SELFTESTRESPONSE._serialized_start=25439
  _SELFTESTRESPONSE._serialized_end=25526
  _SENDSOFTWAREEDGETRIGGERREQUEST._serialized_start=25529
  _SENDSOFTWAREEDGETRIGGERREQUEST._serialized_end=25700
  _SENDSOFTWAREEDGETRIGGERRESPONSE._serialized_start=25702
  _SENDSOFTWAREEDGETRIGGERRESPONSE._serialized_end=25751
  _SENDSOFTWAREEDGETRIGGERWITHCHANNELSREQUEST._serialized_start=25754
  _SENDSOFTWAREEDGETRIGGERWITHCHANNELSREQUEST._serialized_end=25959
  _SENDSOFTWAREEDGETRIGGERWITHCHANNELSRESPONSE._serialized_start=25961
  _SENDSOFTWAREEDGETRIGGERWITHCHANNELSRESPONSE._serialized_end=26022
  _SETATTRIBUTEVIBOOLEANREQUEST._serialized_start=26025
  _SETATTRIBUTEVIBOOLEANREQUEST._serialized_end=26196
  _SETATTRIBUTEVIBOOLEANRESPONSE._serialized_start=26198
  _SETATTRIBUTEVIBOOLEANRESPONSE._serialized_end=26245
  _SETATTRIBUTEVIINT32REQUEST._serialized_start=26248
  _SETATTRIBUTEVIINT32REQUEST._serialized_end=26521
  _SETATTRIBUTEVIINT32RESPONSE._serialized_start=26523
  _SETATTRIBUTEVIINT32RESPONSE._serialized_end=26568
  _SETATTRIBUTEVIINT64REQUEST._serialized_start=26571
  _SETATTRIBUTEVIINT64REQUEST._serialized_end=26744
  _SETATTRIBUTEVIINT64RESPONSE._serialized_start=26746
  _SETATTRIBUTEVIINT64RESPONSE._serialized_end=26791
  _SETATTRIBUTEVIREAL64REQUEST._serialized_start=26794
  _SETATTRIBUTEVIREAL64REQUEST._serialized_end=27069
  _SETATTRIBUTEVIREAL64RESPONSE._serialized_start=27071
  _SETATTRIBUTEVIREAL64RESPONSE._serialized_end=27117
  _SETATTRIBUTEVISESSIONREQUEST._serialized_start=27120
  _SETATTRIBUTEVISESSIONREQUEST._serialized_end=27315
  _SETATTRIBUTEVISESSIONRESPONSE._serialized_start=27317
  _SETATTRIBUTEVISESSIONRESPONSE._serialized_end=27364
  _SETATTRIBUTEVISTRINGREQUEST._serialized_start=27367
  _SETATTRIBUTEVISTRINGREQUEST._serialized_end=27541
  _SETATTRIBUTEVISTRINGRESPONSE._serialized_start=27543
  _SETATTRIBUTEVISTRINGRESPONSE._serialized_end=27589
  _SETSEQUENCEREQUEST._serialized_start=27591
  _SETSEQUENCEREQUEST._serialized_end=27708
  _SETSEQUENCERESPONSE._serialized_start=27710
  _SETSEQUENCERESPONSE._serialized_end=27747
  _WAITFOREVENTREQUEST._serialized_start=27750
  _WAITFOREVENTREQUEST._serialized_end=27908
  _WAITFOREVENTRESPONSE._serialized_start=27910
  _WAITFOREVENTRESPONSE._serialized_end=27948
  _WAITFOREVENTWITHCHANNELSREQUEST._serialized_start=27951
  _WAITFOREVENTWITHCHANNELSREQUEST._serialized_end=28143
  _WAITFOREVENTWITHCHANNELSRESPONSE._serialized_start=28145
  _WAITFOREVENTWITHCHANNELSRESPONSE._serialized_end=28195
  _NIDCPOWER._serialized_start=49855
  _NIDCPOWER._serialized_end=68958
# @@protoc_insertion_point(module_scope)
